# 15 "src/ocaml/typer/preprocess/lexer_raw.mll"

open Std
open Misc
open Lexing
open Parser_raw

type keywords = (string, Parser_raw.token) Hashtbl.t

type error =
  | Illegal_character of char
  | Illegal_escape of string
  | Unterminated_comment of Location.t
  | Unterminated_string
  | Unterminated_string_in_comment of Location.t * Location.t
  | Keyword_as_label of string
  | Invalid_literal of string

exception Error of error * Location.t

(* Monad in which the lexer evaluates *)
type 'a result =
  | Return of 'a
  | Refill of (unit -> 'a result)
  | Fail of error * Location.t

let return a = Return a

let fail e l = Fail (e,l)

let rec (>>=) (m : 'a result) (f : 'a -> 'b result) : 'b result =
  match m with
  | Return a -> f a
  | Refill u ->
    Refill (fun () -> u () >>= f)
  | Fail _ as e -> e

type preprocessor = (Lexing.lexbuf -> Parser_raw.token) -> Lexing.lexbuf -> Parser_raw.token

type state = {
  keywords: keywords;
  mutable buffer: Buffer.t;
  mutable string_start_loc: Location.t;
  mutable comment_start_loc: Location.t list;
  mutable preprocessor: preprocessor option;
}

let make ?preprocessor keywords = {
  keywords;
  buffer = Buffer.create 17;
  string_start_loc = Location.none;
  comment_start_loc = [];
  preprocessor;
}

let lABEL m = m >>= fun v -> return (LABEL v)
let oPTLABEL m = m >>= fun v -> return (OPTLABEL v)

let rec catch m f = match m with
  | Fail (e,l) -> f e l
  | Refill next -> Refill (fun () -> catch (next ()) f)
  | Return _ -> m

(* The table of keywords *)

let keyword_table : keywords =
  create_hashtable 149 [
    "and", AND;
    "as", AS;
    "assert", ASSERT;
    "begin", BEGIN;
    "class", CLASS;
    "constraint", CONSTRAINT;
    "do", DO;
    "done", DONE;
    "downto", DOWNTO;
    "else", ELSE;
    "end", END;
    "exception", EXCEPTION;
    "external", EXTERNAL;
    "false", FALSE;
    "for", FOR;
    "fun", FUN;
    "function", FUNCTION;
    "functor", FUNCTOR;
    "if", IF;
    "in", IN;
    "include", INCLUDE;
    "inherit", INHERIT;
    "initializer", INITIALIZER;
    "lazy", LAZY;
    "let", LET;
    "match", MATCH;
    "method", METHOD;
    "module", MODULE;
    "mutable", MUTABLE;
    "new", NEW;
    "nonrec", NONREC;
    "object", OBJECT;
    "of", OF;
    "open", OPEN;
    "or", OR;
(*  "parser", PARSER; *)
    "private", PRIVATE;
    "rec", REC;
    "sig", SIG;
    "struct", STRUCT;
    "then", THEN;
    "to", TO;
    "true", TRUE;
    "try", TRY;
    "type", TYPE;
    "val", VAL;
    "virtual", VIRTUAL;
    "when", WHEN;
    "while", WHILE;
    "with", WITH;

    "lor", INFIXOP3("lor"); (* Should be INFIXOP2 *)
    "lxor", INFIXOP3("lxor"); (* Should be INFIXOP2 *)
    "mod", INFIXOP3("mod");
    "land", INFIXOP3("land");
    "lsl", INFIXOP4("lsl");
    "lsr", INFIXOP4("lsr");
    "asr", INFIXOP4("asr");
]

let keywords l = create_hashtable 11 l

(* To store the position of the beginning of a string and comment *)
let in_comment state = state.comment_start_loc <> []
let in_string state = state.string_start_loc != Location.none

(* Escaped chars are interpreted in strings unless they are in comments. *)
let store_escaped_char state lexbuf c =
    if in_comment state
    then Buffer.add_string state.buffer (Lexing.lexeme lexbuf)
    else Buffer.add_char state.buffer c

(* To translate escape sequences *)

let char_for_backslash = function
  | 'n' -> '\010'
  | 'r' -> '\013'
  | 'b' -> '\008'
  | 't' -> '\009'
  | c   -> c

let char_for_decimal_code state lexbuf i =
  let c = 100 * (Char.code(Lexing.lexeme_char lexbuf i) - 48) +
           10 * (Char.code(Lexing.lexeme_char lexbuf (i+1)) - 48) +
                (Char.code(Lexing.lexeme_char lexbuf (i+2)) - 48) in
  if (c < 0 || c > 255) then
    if in_comment state
    then return 'x'
    else fail (Illegal_escape (Lexing.lexeme lexbuf))
               (Location.curr lexbuf)
  else return (Char.chr c)

let char_for_octal_code lexbuf i =
  let c = 64 * (Char.code(Lexing.lexeme_char lexbuf i) - 48) +
           8 * (Char.code(Lexing.lexeme_char lexbuf (i+1)) - 48) +
               (Char.code(Lexing.lexeme_char lexbuf (i+2)) - 48) in
  Char.chr c

let char_for_hexadecimal_code lexbuf i =
  let d1 = Char.code (Lexing.lexeme_char lexbuf i) in
  let val1 = if d1 >= 97 then d1 - 87
             else if d1 >= 65 then d1 - 55
             else d1 - 48
  in
  let d2 = Char.code (Lexing.lexeme_char lexbuf (i+1)) in
  let val2 = if d2 >= 97 then d2 - 87
             else if d2 >= 65 then d2 - 55
             else d2 - 48
  in
  Char.chr (val1 * 16 + val2)

let keyword_or state s default =
  try Hashtbl.find state.keywords s
      with Not_found -> try Hashtbl.find keyword_table s
  with Not_found -> default

(* recover the name from a LABEL or OPTLABEL token *)

let get_label_name lexbuf =
  let s = Lexing.lexeme lexbuf in
  let name = String.sub s 1 (String.length s - 2) in
  if Hashtbl.mem keyword_table name then
    fail (Keyword_as_label name) (Location.curr lexbuf)
  else
    return name
;;

(* Update the current location with file name and line number. *)

let update_loc lexbuf file line absolute chars =
  let pos = lexbuf.lex_curr_p in
  let new_file = match file with
                 | None -> pos.pos_fname
                 | Some s -> s
  in
  lexbuf.lex_curr_p <- { pos with
    pos_fname = new_file;
    pos_lnum = if absolute then line else pos.pos_lnum + line;
    pos_bol = pos.pos_cnum - chars;
  }
;;

(* Warn about Latin-1 characters used in idents *)

let warn_latin1 lexbuf =
  Location.prerr_warning (Location.curr lexbuf)
    (Warnings.Deprecated "ISO-Latin1 characters in identifiers")
;;

(* Error report *)

open Format

let report_error ppf = function
  | Illegal_character c ->
      fprintf ppf "Illegal character (%s)" (Char.escaped c)
  | Illegal_escape s ->
      fprintf ppf "Illegal backslash escape in string or character (%s)" s
  | Unterminated_comment _ ->
      fprintf ppf "Comment not terminated"
  | Unterminated_string ->
      fprintf ppf "String literal not terminated"
  | Unterminated_string_in_comment (_, loc) ->
      fprintf ppf "This comment contains an unterminated string literal@.\
                   %aString literal begins here"
              Location.print_error loc
  | Keyword_as_label kwd ->
      fprintf ppf "`%s' is a keyword, it cannot be used as label name" kwd
  | Invalid_literal s ->
      fprintf ppf "Invalid literal %s" s

let () =
  Location.register_error_of_exn
    (function
      | Error (err, loc) ->
        Some (Location.error_of_printer loc report_error err)
      | _ ->
        None
    )


# 250 "src/ocaml/typer/lexer_raw.ml"
let __ocaml_lex_refill : (Lexing.lexbuf -> 'a) -> (Lexing.lexbuf -> 'a) =
# 298 "src/ocaml/typer/preprocess/lexer_raw.mll"
       (fun k lexbuf -> Refill (fun () -> k lexbuf))
# 254 "src/ocaml/typer/lexer_raw.ml"
let __ocaml_lex_tables = {
  Lexing.lex_base =
   "\000\000\161\255\162\255\224\000\003\001\038\001\073\001\108\001\
    \143\001\186\255\178\001\194\255\091\000\215\001\250\001\068\000\
    \071\000\029\002\211\255\213\255\216\255\064\002\159\002\194\002\
    \088\000\255\000\224\002\232\255\093\003\221\003\099\004\227\004\
    \105\005\233\005\014\006\106\006\106\007\143\007\121\000\122\000\
    \254\255\001\000\005\000\255\255\006\000\007\000\208\255\250\255\
    \252\255\185\255\187\255\180\007\215\007\107\008\235\008\247\255\
    \246\255\113\009\241\009\022\010\243\255\242\255\151\010\023\011\
    \177\011\049\012\183\012\055\013\189\013\061\014\022\015\150\015\
    \048\016\087\000\176\016\054\017\182\017\080\018\208\018\108\000\
    \192\255\231\255\192\002\049\019\106\000\107\000\011\000\230\255\
    \229\255\224\255\081\002\120\000\099\000\113\000\228\255\134\000\
    \224\000\127\000\227\255\003\001\139\000\226\255\099\004\140\000\
    \225\255\139\000\222\255\049\019\221\255\088\019\027\005\194\002\
    \220\255\012\000\014\001\034\001\080\001\024\001\220\255\013\000\
    \134\019\173\019\208\019\246\019\204\255\205\255\206\255\202\255\
    \025\020\153\000\127\000\195\255\196\255\197\255\194\000\182\255\
    \180\255\189\255\060\020\095\020\130\020\165\020\200\020\171\004\
    \243\255\244\255\017\000\245\255\069\001\175\006\253\255\218\000\
    \221\000\255\255\254\255\252\255\203\006\232\007\225\000\242\000\
    \018\000\251\255\250\255\249\255\124\005\211\002\250\000\248\255\
    \221\002\252\000\247\255\107\008\003\001\246\255\059\001\139\001\
    \247\255\248\255\249\255\060\001\000\021\255\255\250\255\235\008\
    \122\004\253\255\094\001\094\001\111\001\227\004\252\255\113\009\
    \251\255\112\001\165\001\252\255\077\006\254\255\255\255\129\001\
    \130\001\253\255\020\010\008\001\044\001\068\001\077\001\053\001\
    \078\001\060\001\019\000\255\255";
  Lexing.lex_backtrk =
   "\255\255\255\255\255\255\090\000\089\000\086\000\085\000\078\000\
    \076\000\255\255\064\000\255\255\057\000\056\000\054\000\052\000\
    \048\000\081\000\255\255\255\255\255\255\037\000\036\000\043\000\
    \041\000\040\000\062\000\255\255\018\000\018\000\017\000\016\000\
    \015\000\014\000\010\000\007\000\006\000\067\000\046\000\002\000\
    \255\255\094\000\094\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\004\000\084\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\011\000\255\255\255\255\022\000\022\000\
    \020\000\019\000\022\000\019\000\019\000\018\000\020\000\019\000\
    \020\000\255\255\021\000\021\000\018\000\018\000\020\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\031\000\031\000\031\000\031\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\032\000\255\255\088\000\255\255\091\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \038\000\087\000\082\000\045\000\255\255\255\255\255\255\255\255\
    \055\000\074\000\071\000\255\255\255\255\255\255\072\000\255\255\
    \255\255\255\255\065\000\083\000\077\000\080\000\079\000\255\255\
    \255\255\255\255\012\000\255\255\012\000\012\000\255\255\012\000\
    \012\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\008\000\008\000\255\255\255\255\005\000\
    \005\000\255\255\001\000\005\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\003\000\255\255\255\255\003\000\
    \255\255\255\255\255\255\002\000\255\255\255\255\001\000\255\255\
    \255\255\255\255\255\255\255\255";
  Lexing.lex_default =
   "\001\000\000\000\000\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\000\000\255\255\000\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\000\000\000\000\000\000\255\255\255\255\255\255\
    \255\255\084\000\255\255\000\000\062\000\062\000\030\000\031\000\
    \032\000\033\000\255\255\255\255\033\000\255\255\255\255\255\255\
    \000\000\255\255\255\255\000\000\255\255\255\255\000\000\000\000\
    \000\000\000\000\000\000\255\255\255\255\053\000\054\000\000\000\
    \000\000\057\000\058\000\255\255\000\000\000\000\062\000\062\000\
    \062\000\062\000\062\000\062\000\062\000\062\000\062\000\062\000\
    \062\000\255\255\062\000\062\000\062\000\062\000\062\000\255\255\
    \000\000\000\000\255\255\089\000\255\255\255\255\255\255\000\000\
    \000\000\000\000\255\255\255\255\255\255\255\255\000\000\255\255\
    \255\255\255\255\000\000\255\255\255\255\000\000\255\255\255\255\
    \000\000\255\255\000\000\255\255\000\000\255\255\114\000\255\255\
    \000\000\255\255\114\000\115\000\114\000\117\000\000\000\255\255\
    \255\255\255\255\255\255\255\255\000\000\000\000\000\000\000\000\
    \255\255\255\255\255\255\000\000\000\000\000\000\255\255\000\000\
    \000\000\000\000\255\255\255\255\255\255\255\255\255\255\144\000\
    \000\000\000\000\255\255\000\000\158\000\255\255\000\000\255\255\
    \255\255\000\000\000\000\000\000\255\255\255\255\255\255\255\255\
    \255\255\000\000\000\000\000\000\255\255\255\255\255\255\000\000\
    \255\255\255\255\000\000\255\255\255\255\000\000\255\255\176\000\
    \000\000\000\000\000\000\255\255\182\000\000\000\000\000\255\255\
    \255\255\000\000\255\255\255\255\255\255\255\255\000\000\255\255\
    \000\000\255\255\195\000\000\000\255\255\000\000\000\000\255\255\
    \255\255\000\000\255\255\255\255\255\255\205\000\208\000\255\255\
    \208\000\255\255\255\255\000\000";
  Lexing.lex_trans =
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\039\000\040\000\040\000\039\000\041\000\045\000\043\000\
    \043\000\040\000\044\000\044\000\045\000\085\000\112\000\118\000\
    \086\000\113\000\119\000\145\000\159\000\211\000\174\000\160\000\
    \039\000\008\000\027\000\022\000\006\000\004\000\021\000\025\000\
    \024\000\019\000\023\000\007\000\018\000\017\000\038\000\003\000\
    \029\000\028\000\028\000\028\000\028\000\028\000\028\000\028\000\
    \028\000\028\000\016\000\015\000\014\000\013\000\037\000\034\000\
    \005\000\031\000\031\000\031\000\031\000\031\000\031\000\031\000\
    \031\000\031\000\031\000\031\000\031\000\031\000\031\000\031\000\
    \031\000\031\000\031\000\031\000\031\000\031\000\031\000\031\000\
    \031\000\031\000\031\000\012\000\042\000\011\000\005\000\036\000\
    \020\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\026\000\010\000\009\000\035\000\127\000\
    \129\000\126\000\105\000\039\000\125\000\124\000\039\000\072\000\
    \072\000\072\000\072\000\072\000\072\000\072\000\072\000\072\000\
    \072\000\088\000\087\000\095\000\095\000\095\000\095\000\132\000\
    \094\000\131\000\039\000\130\000\078\000\078\000\078\000\078\000\
    \078\000\078\000\078\000\078\000\078\000\078\000\098\000\046\000\
    \099\000\099\000\099\000\099\000\099\000\099\000\099\000\099\000\
    \099\000\099\000\101\000\104\000\106\000\048\000\096\000\096\000\
    \096\000\096\000\096\000\096\000\096\000\096\000\136\000\134\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\133\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\047\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \002\000\003\000\135\000\154\000\003\000\003\000\003\000\153\000\
    \163\000\085\000\003\000\003\000\086\000\003\000\003\000\003\000\
    \097\000\097\000\097\000\097\000\097\000\097\000\097\000\097\000\
    \112\000\162\000\003\000\113\000\003\000\003\000\003\000\003\000\
    \003\000\167\000\118\000\170\000\003\000\119\000\255\255\003\000\
    \003\000\003\000\173\000\204\000\112\000\003\000\003\000\113\000\
    \003\000\003\000\003\000\100\000\100\000\100\000\100\000\100\000\
    \100\000\100\000\100\000\100\000\100\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\003\000\117\000\145\000\178\000\005\000\
    \174\000\193\000\005\000\005\000\005\000\205\000\206\000\159\000\
    \005\000\005\000\160\000\005\000\005\000\005\000\209\000\207\000\
    \207\000\116\000\112\000\083\000\003\000\113\000\003\000\210\000\
    \005\000\003\000\005\000\005\000\005\000\005\000\005\000\186\000\
    \186\000\000\000\006\000\188\000\161\000\006\000\006\000\006\000\
    \116\000\000\000\115\000\006\000\006\000\000\000\006\000\006\000\
    \006\000\186\000\178\000\000\000\188\000\193\000\186\000\003\000\
    \000\000\003\000\000\000\006\000\005\000\006\000\006\000\006\000\
    \006\000\006\000\000\000\198\000\198\000\121\000\200\000\200\000\
    \121\000\121\000\121\000\000\000\000\000\178\000\121\000\121\000\
    \179\000\121\000\142\000\121\000\000\000\000\000\000\000\000\000\
    \000\000\157\000\005\000\000\000\005\000\000\000\121\000\006\000\
    \121\000\141\000\121\000\121\000\121\000\181\000\000\000\198\000\
    \139\000\000\000\199\000\139\000\139\000\139\000\000\000\000\000\
    \000\000\139\000\139\000\000\000\139\000\139\000\139\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\006\000\000\000\006\000\
    \000\000\139\000\121\000\139\000\140\000\139\000\139\000\139\000\
    \000\000\000\000\000\000\006\000\000\000\000\000\006\000\006\000\
    \006\000\000\000\000\000\000\000\006\000\006\000\000\000\006\000\
    \006\000\006\000\000\000\000\000\000\000\000\000\000\000\180\000\
    \121\000\000\000\121\000\000\000\006\000\139\000\006\000\006\000\
    \006\000\006\000\006\000\000\000\000\000\000\000\000\000\000\000\
    \006\000\000\000\000\000\006\000\006\000\006\000\000\000\255\255\
    \000\000\006\000\006\000\000\000\006\000\006\000\006\000\000\000\
    \000\000\000\000\000\000\139\000\000\000\139\000\255\255\137\000\
    \006\000\006\000\000\000\006\000\006\000\006\000\006\000\006\000\
    \255\255\000\000\000\000\006\000\000\000\000\000\006\000\006\000\
    \006\000\196\000\255\255\000\000\006\000\006\000\000\000\128\000\
    \006\000\006\000\000\000\000\000\000\000\000\000\138\000\000\000\
    \006\000\000\000\000\000\000\000\006\000\006\000\006\000\006\000\
    \006\000\006\000\006\000\000\000\000\000\000\000\121\000\000\000\
    \000\000\121\000\121\000\121\000\255\255\255\255\000\000\121\000\
    \121\000\000\000\121\000\122\000\121\000\255\255\255\255\000\000\
    \255\255\000\000\000\000\006\000\000\000\006\000\000\000\121\000\
    \006\000\121\000\121\000\123\000\121\000\121\000\000\000\000\000\
    \000\000\006\000\000\000\000\000\006\000\006\000\120\000\000\000\
    \000\000\000\000\006\000\006\000\000\000\006\000\006\000\006\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\006\000\000\000\
    \006\000\000\000\006\000\121\000\006\000\006\000\006\000\006\000\
    \006\000\102\000\102\000\102\000\102\000\102\000\102\000\102\000\
    \102\000\102\000\102\000\177\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\102\000\102\000\102\000\102\000\102\000\102\000\
    \000\000\121\000\000\000\121\000\000\000\000\000\006\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\197\000\000\000\000\000\
    \111\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\102\000\102\000\102\000\102\000\102\000\102\000\
    \000\000\000\000\000\000\000\000\006\000\000\000\006\000\111\000\
    \109\000\000\000\109\000\109\000\109\000\109\000\000\000\000\000\
    \000\000\109\000\109\000\111\000\109\000\109\000\109\000\110\000\
    \110\000\110\000\110\000\110\000\110\000\110\000\110\000\110\000\
    \110\000\109\000\000\000\109\000\109\000\109\000\109\000\109\000\
    \000\000\000\000\111\000\003\000\000\000\000\000\003\000\003\000\
    \003\000\000\000\000\000\108\000\107\000\003\000\000\000\003\000\
    \003\000\003\000\110\000\110\000\110\000\110\000\110\000\110\000\
    \110\000\110\000\110\000\110\000\003\000\109\000\003\000\003\000\
    \003\000\003\000\003\000\168\000\168\000\168\000\168\000\168\000\
    \168\000\168\000\168\000\168\000\168\000\169\000\169\000\169\000\
    \169\000\169\000\169\000\169\000\169\000\169\000\169\000\000\000\
    \000\000\000\000\000\000\109\000\080\000\109\000\000\000\082\000\
    \003\000\082\000\082\000\082\000\082\000\082\000\082\000\082\000\
    \082\000\082\000\082\000\082\000\082\000\082\000\082\000\082\000\
    \082\000\082\000\082\000\082\000\082\000\082\000\082\000\082\000\
    \082\000\082\000\082\000\000\000\081\000\000\000\003\000\082\000\
    \003\000\082\000\082\000\082\000\082\000\082\000\082\000\082\000\
    \082\000\082\000\082\000\082\000\082\000\082\000\082\000\082\000\
    \082\000\082\000\082\000\082\000\082\000\082\000\082\000\082\000\
    \082\000\082\000\082\000\000\000\081\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\000\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\064\000\255\255\028\000\028\000\028\000\
    \028\000\028\000\028\000\028\000\028\000\028\000\028\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\000\000\000\000\
    \000\000\000\000\063\000\000\000\065\000\065\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\065\000\065\000\
    \255\255\255\255\255\255\255\255\028\000\255\255\000\000\000\000\
    \000\000\000\000\063\000\000\000\065\000\065\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\065\000\065\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\000\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\064\000\255\255\028\000\028\000\028\000\
    \028\000\028\000\028\000\028\000\028\000\028\000\028\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\000\000\066\000\
    \000\000\000\000\063\000\000\000\065\000\065\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\067\000\065\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\068\000\065\000\065\000\
    \255\255\255\255\255\255\255\255\028\000\255\255\000\000\066\000\
    \000\000\000\000\063\000\000\000\065\000\065\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\067\000\065\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\068\000\065\000\065\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\000\000\000\000\
    \000\000\000\000\000\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\000\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\103\000\103\000\103\000\103\000\103\000\
    \103\000\103\000\103\000\103\000\103\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\103\000\103\000\103\000\103\000\
    \103\000\103\000\189\000\189\000\189\000\189\000\189\000\189\000\
    \189\000\189\000\189\000\189\000\000\000\145\000\000\000\000\000\
    \146\000\000\000\000\000\000\000\000\000\000\000\255\255\255\255\
    \255\255\255\255\000\000\255\255\103\000\103\000\103\000\103\000\
    \103\000\103\000\000\000\000\000\000\000\150\000\000\000\000\000\
    \000\000\000\000\148\000\152\000\000\000\151\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\000\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\190\000\190\000\190\000\190\000\190\000\
    \190\000\190\000\190\000\190\000\190\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\116\000\112\000\149\000\000\000\
    \113\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\116\000\000\000\115\000\255\255\255\255\
    \255\255\255\255\000\000\255\255\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\110\000\110\000\110\000\110\000\110\000\
    \110\000\110\000\110\000\110\000\110\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\000\000\000\000\000\000\000\000\
    \000\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \000\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\000\000\147\000\171\000\171\000\171\000\171\000\
    \171\000\171\000\171\000\171\000\171\000\171\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\171\000\171\000\171\000\
    \171\000\171\000\171\000\000\000\255\255\255\255\255\255\255\255\
    \000\000\255\255\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\171\000\171\000\171\000\
    \171\000\171\000\171\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \000\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\000\000\000\000\255\255\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\000\000\000\000\000\000\000\000\000\000\052\000\
    \000\000\000\000\052\000\052\000\052\000\000\000\000\000\000\000\
    \052\000\052\000\000\000\052\000\052\000\052\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\255\255\255\255\255\255\255\255\
    \052\000\255\255\052\000\052\000\052\000\059\000\052\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\000\000\000\000\052\000\058\000\000\000\058\000\
    \058\000\058\000\058\000\058\000\058\000\058\000\058\000\058\000\
    \058\000\058\000\058\000\058\000\058\000\058\000\058\000\058\000\
    \058\000\058\000\058\000\058\000\058\000\058\000\058\000\058\000\
    \058\000\000\000\052\000\052\000\052\000\000\000\052\000\052\000\
    \052\000\000\000\000\000\000\000\052\000\052\000\000\000\052\000\
    \052\000\052\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\052\000\000\000\052\000\052\000\
    \052\000\052\000\052\000\000\000\202\000\000\000\202\000\202\000\
    \202\000\202\000\202\000\202\000\202\000\202\000\202\000\202\000\
    \202\000\202\000\202\000\202\000\202\000\202\000\202\000\202\000\
    \202\000\202\000\202\000\202\000\202\000\202\000\202\000\202\000\
    \052\000\054\000\201\000\054\000\054\000\054\000\054\000\054\000\
    \054\000\054\000\054\000\054\000\054\000\054\000\054\000\054\000\
    \054\000\054\000\054\000\054\000\054\000\054\000\054\000\054\000\
    \054\000\054\000\054\000\054\000\054\000\000\000\052\000\000\000\
    \052\000\255\255\000\000\000\000\000\000\057\000\057\000\057\000\
    \057\000\057\000\057\000\057\000\057\000\057\000\057\000\057\000\
    \057\000\057\000\057\000\057\000\057\000\057\000\057\000\057\000\
    \057\000\057\000\057\000\057\000\057\000\000\000\057\000\057\000\
    \057\000\057\000\057\000\057\000\057\000\057\000\156\000\000\000\
    \156\000\156\000\156\000\156\000\156\000\156\000\156\000\156\000\
    \156\000\156\000\156\000\156\000\156\000\156\000\156\000\156\000\
    \156\000\156\000\156\000\156\000\156\000\156\000\156\000\156\000\
    \156\000\156\000\156\000\155\000\156\000\156\000\156\000\156\000\
    \156\000\156\000\156\000\156\000\156\000\156\000\156\000\156\000\
    \156\000\156\000\156\000\156\000\156\000\156\000\156\000\156\000\
    \156\000\156\000\156\000\156\000\156\000\156\000\000\000\155\000\
    \000\000\053\000\053\000\053\000\053\000\053\000\053\000\053\000\
    \053\000\053\000\053\000\053\000\053\000\053\000\053\000\053\000\
    \053\000\053\000\053\000\053\000\053\000\053\000\053\000\053\000\
    \053\000\000\000\053\000\053\000\053\000\053\000\053\000\053\000\
    \053\000\053\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\000\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\000\000\000\000\000\000\000\000\000\000\
    \006\000\000\000\000\000\006\000\006\000\006\000\000\000\000\000\
    \000\000\006\000\006\000\000\000\006\000\051\000\006\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\255\255\255\255\255\255\
    \255\255\006\000\255\255\006\000\006\000\006\000\006\000\006\000\
    \000\000\000\000\000\000\000\000\000\000\006\000\000\000\000\000\
    \006\000\006\000\006\000\000\000\000\000\000\000\006\000\006\000\
    \000\000\006\000\006\000\006\000\000\000\255\255\255\255\255\255\
    \255\255\255\255\000\000\000\000\050\000\006\000\006\000\000\000\
    \006\000\006\000\006\000\006\000\006\000\000\000\000\000\000\000\
    \052\000\000\000\000\000\052\000\052\000\052\000\000\000\000\000\
    \000\000\052\000\052\000\000\000\052\000\052\000\052\000\000\000\
    \166\000\000\000\166\000\006\000\049\000\006\000\000\000\166\000\
    \000\000\052\000\006\000\052\000\052\000\052\000\052\000\052\000\
    \165\000\165\000\165\000\165\000\165\000\165\000\165\000\165\000\
    \165\000\165\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \006\000\000\000\006\000\000\000\000\000\052\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\166\000\000\000\000\000\000\000\
    \000\000\000\000\166\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\052\000\000\000\052\000\166\000\000\000\
    \000\000\000\000\166\000\000\000\166\000\000\000\000\000\000\000\
    \164\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\000\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\172\000\172\000\172\000\172\000\172\000\
    \172\000\172\000\172\000\172\000\172\000\056\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\172\000\172\000\172\000\172\000\
    \172\000\172\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\255\255\255\255\
    \255\255\255\255\000\000\255\255\172\000\172\000\172\000\172\000\
    \172\000\172\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\000\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\191\000\191\000\191\000\191\000\191\000\
    \191\000\191\000\191\000\191\000\191\000\055\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\191\000\191\000\191\000\191\000\
    \191\000\191\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\255\255\255\255\
    \255\255\255\255\000\000\255\255\191\000\191\000\191\000\191\000\
    \191\000\191\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\000\000\000\000\000\000\000\000\
    \000\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \000\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\192\000\192\000\192\000\192\000\192\000\192\000\192\000\
    \192\000\192\000\192\000\061\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\192\000\192\000\192\000\192\000\192\000\192\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\255\255\255\255\255\255\255\255\
    \000\000\255\255\192\000\192\000\192\000\192\000\192\000\192\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \000\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\060\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\000\000\000\000\000\000\000\000\000\000\052\000\
    \000\000\000\000\052\000\052\000\052\000\000\000\000\000\000\000\
    \052\000\052\000\000\000\052\000\052\000\052\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\255\255\255\255\255\255\255\255\
    \052\000\255\255\052\000\052\000\052\000\052\000\052\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\000\000\202\000\052\000\202\000\202\000\202\000\
    \202\000\202\000\202\000\202\000\202\000\202\000\202\000\202\000\
    \202\000\202\000\202\000\202\000\202\000\202\000\202\000\202\000\
    \202\000\202\000\202\000\202\000\202\000\202\000\202\000\000\000\
    \000\000\201\000\052\000\000\000\052\000\000\000\000\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\000\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\255\255\255\255\255\255\255\255\255\255\000\000\255\255\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\000\000\255\255\
    \255\255\255\255\079\000\255\255\079\000\255\255\255\255\078\000\
    \078\000\078\000\078\000\078\000\078\000\078\000\078\000\078\000\
    \078\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\255\255\255\255\255\255\255\255\000\000\255\255\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \000\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\064\000\064\000\064\000\064\000\064\000\064\000\064\000\
    \064\000\064\000\064\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\000\000\000\000\000\000\000\000\063\000\000\000\
    \074\000\074\000\074\000\074\000\074\000\074\000\074\000\074\000\
    \074\000\074\000\074\000\074\000\074\000\074\000\074\000\074\000\
    \074\000\074\000\074\000\074\000\255\255\255\255\255\255\255\255\
    \064\000\255\255\000\000\000\000\000\000\000\000\063\000\255\255\
    \074\000\074\000\074\000\074\000\074\000\074\000\074\000\074\000\
    \074\000\074\000\074\000\074\000\074\000\074\000\074\000\074\000\
    \074\000\074\000\074\000\074\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \000\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\255\255\255\255\255\255\255\255\
    \000\000\255\255\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\000\000\000\000\000\000\000\000\000\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\000\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\077\000\
    \077\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\255\255\255\255\255\255\255\255\000\000\255\255\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\000\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\076\000\
    \076\000\076\000\076\000\076\000\076\000\076\000\076\000\000\000\
    \000\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\255\255\255\255\255\255\255\255\000\000\255\255\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \000\000\000\000\000\000\000\000\000\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\000\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\069\000\069\000\069\000\
    \069\000\069\000\069\000\069\000\069\000\069\000\069\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\069\000\069\000\
    \069\000\069\000\069\000\069\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \255\255\255\255\255\255\255\255\000\000\255\255\069\000\069\000\
    \069\000\069\000\069\000\069\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\000\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\070\000\255\255\069\000\069\000\069\000\
    \069\000\069\000\069\000\069\000\069\000\069\000\069\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\069\000\069\000\
    \069\000\069\000\069\000\069\000\065\000\065\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\071\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\065\000\065\000\
    \255\255\255\255\255\255\255\255\069\000\255\255\069\000\069\000\
    \069\000\069\000\069\000\069\000\065\000\065\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\071\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\065\000\065\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\070\000\070\000\
    \070\000\070\000\070\000\070\000\070\000\070\000\070\000\070\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\070\000\
    \070\000\070\000\070\000\070\000\070\000\074\000\074\000\074\000\
    \074\000\074\000\074\000\074\000\074\000\074\000\075\000\074\000\
    \074\000\074\000\074\000\074\000\074\000\074\000\074\000\074\000\
    \074\000\255\255\255\255\255\255\255\255\070\000\255\255\070\000\
    \070\000\070\000\070\000\070\000\070\000\074\000\074\000\074\000\
    \074\000\074\000\074\000\074\000\074\000\074\000\075\000\074\000\
    \074\000\074\000\074\000\074\000\074\000\074\000\074\000\074\000\
    \074\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\000\000\255\255\255\255\
    \255\255\073\000\255\255\073\000\255\255\255\255\072\000\072\000\
    \072\000\072\000\072\000\072\000\072\000\072\000\072\000\072\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\255\255\255\255\255\255\255\255\000\000\255\255\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\255\255\255\255\255\255\255\255\255\255\255\255\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\000\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \072\000\072\000\072\000\072\000\072\000\072\000\072\000\072\000\
    \072\000\072\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\000\000\000\000\000\000\000\000\000\000\000\000\074\000\
    \074\000\074\000\074\000\074\000\074\000\074\000\074\000\074\000\
    \074\000\074\000\074\000\074\000\074\000\074\000\074\000\074\000\
    \074\000\074\000\074\000\255\255\255\255\255\255\255\255\072\000\
    \255\255\000\000\000\000\000\000\000\000\000\000\255\255\074\000\
    \074\000\074\000\074\000\074\000\074\000\074\000\074\000\074\000\
    \074\000\074\000\074\000\074\000\074\000\074\000\074\000\074\000\
    \074\000\074\000\074\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\000\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\255\255\255\255\255\255\255\255\000\000\
    \255\255\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\000\000\000\000\000\000\000\000\000\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\000\000\255\255\255\255\
    \255\255\073\000\255\255\073\000\255\255\255\255\072\000\072\000\
    \072\000\072\000\072\000\072\000\072\000\072\000\072\000\072\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\255\255\255\255\255\255\255\255\000\000\255\255\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\000\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\076\000\076\000\
    \076\000\076\000\076\000\076\000\076\000\076\000\000\000\000\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\000\000\
    \000\000\000\000\000\000\000\000\000\000\065\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\065\000\065\000\
    \065\000\255\255\255\255\255\255\255\255\076\000\255\255\000\000\
    \000\000\000\000\000\000\000\000\000\000\065\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\065\000\065\000\
    \065\000\255\255\255\255\255\255\255\255\255\255\255\255\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\000\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \077\000\077\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\000\000\000\000\000\000\000\000\000\000\000\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\065\000\065\000\
    \065\000\065\000\065\000\255\255\255\255\255\255\255\255\077\000\
    \255\255\000\000\000\000\000\000\000\000\000\000\255\255\065\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\065\000\065\000\
    \065\000\065\000\065\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\000\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \078\000\078\000\078\000\078\000\078\000\078\000\078\000\078\000\
    \078\000\078\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\000\000\000\000\000\000\000\000\000\000\000\000\074\000\
    \074\000\074\000\074\000\074\000\074\000\074\000\074\000\074\000\
    \074\000\074\000\074\000\074\000\074\000\074\000\074\000\074\000\
    \074\000\074\000\074\000\255\255\255\255\255\255\255\255\078\000\
    \255\255\000\000\000\000\000\000\000\000\000\000\000\000\074\000\
    \074\000\074\000\074\000\074\000\074\000\074\000\074\000\074\000\
    \074\000\074\000\074\000\074\000\074\000\074\000\074\000\074\000\
    \074\000\074\000\074\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\093\000\107\000\093\000\000\000\107\000\107\000\107\000\
    \093\000\000\000\000\000\107\000\107\000\000\000\107\000\107\000\
    \107\000\091\000\091\000\091\000\091\000\091\000\091\000\091\000\
    \091\000\091\000\091\000\107\000\000\000\107\000\107\000\107\000\
    \107\000\107\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\109\000\000\000\109\000\109\000\109\000\109\000\000\000\
    \000\000\000\000\109\000\109\000\000\000\109\000\109\000\109\000\
    \000\000\000\000\000\000\000\000\000\000\093\000\000\000\107\000\
    \000\000\000\000\109\000\093\000\109\000\109\000\109\000\109\000\
    \109\000\000\000\000\000\000\000\000\000\000\000\000\000\093\000\
    \092\000\000\000\000\000\093\000\000\000\093\000\000\000\006\000\
    \000\000\090\000\006\000\006\000\006\000\107\000\000\000\107\000\
    \006\000\006\000\000\000\006\000\006\000\006\000\109\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \006\000\000\000\006\000\006\000\006\000\006\000\006\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\121\000\000\000\
    \255\255\121\000\121\000\121\000\109\000\000\000\109\000\121\000\
    \121\000\000\000\121\000\121\000\121\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\006\000\000\000\000\000\121\000\
    \000\000\121\000\121\000\121\000\121\000\121\000\000\000\000\000\
    \000\000\121\000\000\000\000\000\121\000\121\000\121\000\000\000\
    \000\000\000\000\121\000\121\000\000\000\121\000\121\000\121\000\
    \000\000\000\000\006\000\000\000\006\000\000\000\000\000\000\000\
    \000\000\000\000\121\000\121\000\121\000\121\000\121\000\121\000\
    \121\000\000\000\000\000\000\000\000\000\000\000\000\000\121\000\
    \000\000\000\000\121\000\121\000\121\000\000\000\000\000\000\000\
    \121\000\121\000\000\000\121\000\121\000\121\000\000\000\000\000\
    \000\000\121\000\000\000\121\000\000\000\000\000\121\000\000\000\
    \121\000\255\255\121\000\121\000\121\000\121\000\121\000\000\000\
    \000\000\000\000\006\000\000\000\000\000\006\000\006\000\006\000\
    \000\000\000\000\000\000\006\000\006\000\000\000\006\000\006\000\
    \006\000\000\000\000\000\000\000\121\000\000\000\121\000\000\000\
    \000\000\000\000\000\000\006\000\121\000\006\000\006\000\006\000\
    \006\000\006\000\000\000\000\000\000\000\006\000\000\000\000\000\
    \006\000\006\000\006\000\000\000\000\000\000\000\006\000\006\000\
    \000\000\006\000\006\000\006\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\121\000\000\000\121\000\000\000\006\000\006\000\
    \006\000\006\000\006\000\006\000\006\000\000\000\000\000\000\000\
    \139\000\000\000\000\000\139\000\139\000\139\000\000\000\000\000\
    \000\000\139\000\139\000\000\000\139\000\139\000\139\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\006\000\000\000\006\000\
    \000\000\139\000\006\000\139\000\139\000\139\000\139\000\139\000\
    \000\000\000\000\000\000\139\000\000\000\000\000\139\000\139\000\
    \139\000\000\000\000\000\000\000\139\000\139\000\000\000\139\000\
    \139\000\139\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \006\000\000\000\006\000\000\000\139\000\139\000\139\000\139\000\
    \139\000\139\000\139\000\000\000\000\000\000\000\121\000\000\000\
    \000\000\121\000\121\000\121\000\000\000\000\000\000\000\121\000\
    \121\000\000\000\121\000\121\000\121\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\139\000\000\000\139\000\000\000\121\000\
    \139\000\121\000\121\000\121\000\121\000\121\000\000\000\000\000\
    \000\000\121\000\000\000\000\000\121\000\121\000\121\000\000\000\
    \000\000\000\000\121\000\121\000\000\000\121\000\121\000\121\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\139\000\000\000\
    \139\000\000\000\121\000\121\000\121\000\121\000\121\000\121\000\
    \121\000\000\000\186\000\000\000\000\000\187\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \185\000\121\000\185\000\121\000\000\000\000\000\121\000\185\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \184\000\184\000\184\000\184\000\184\000\184\000\184\000\184\000\
    \184\000\184\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\121\000\000\000\121\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\185\000\000\000\000\000\000\000\
    \000\000\000\000\185\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\185\000\000\000\
    \000\000\000\000\185\000\000\000\185\000\000\000\000\000\000\000\
    \183\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \255\255";
  Lexing.lex_check =
   "\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\000\000\000\000\041\000\000\000\000\000\041\000\042\000\
    \044\000\045\000\042\000\044\000\045\000\086\000\113\000\119\000\
    \086\000\113\000\119\000\146\000\160\000\210\000\146\000\160\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\015\000\
    \012\000\016\000\024\000\039\000\016\000\016\000\039\000\073\000\
    \073\000\073\000\073\000\073\000\073\000\073\000\073\000\073\000\
    \073\000\084\000\085\000\092\000\092\000\092\000\092\000\012\000\
    \093\000\012\000\039\000\012\000\079\000\079\000\079\000\079\000\
    \079\000\079\000\079\000\079\000\079\000\079\000\097\000\038\000\
    \091\000\091\000\091\000\091\000\091\000\091\000\091\000\091\000\
    \091\000\091\000\100\000\103\000\105\000\038\000\095\000\095\000\
    \095\000\095\000\095\000\095\000\095\000\095\000\129\000\130\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\012\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\038\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\003\000\134\000\151\000\003\000\003\000\003\000\152\000\
    \158\000\025\000\003\000\003\000\025\000\003\000\003\000\003\000\
    \096\000\096\000\096\000\096\000\096\000\096\000\096\000\096\000\
    \114\000\159\000\003\000\114\000\003\000\003\000\003\000\003\000\
    \003\000\166\000\117\000\169\000\004\000\117\000\025\000\004\000\
    \004\000\004\000\172\000\203\000\115\000\004\000\004\000\115\000\
    \004\000\004\000\004\000\099\000\099\000\099\000\099\000\099\000\
    \099\000\099\000\099\000\099\000\099\000\004\000\003\000\004\000\
    \004\000\004\000\004\000\004\000\115\000\174\000\179\000\005\000\
    \174\000\179\000\005\000\005\000\005\000\204\000\205\000\148\000\
    \005\000\005\000\148\000\005\000\005\000\005\000\207\000\206\000\
    \208\000\116\000\116\000\025\000\003\000\116\000\003\000\209\000\
    \005\000\004\000\005\000\005\000\005\000\005\000\005\000\186\000\
    \187\000\255\255\006\000\187\000\148\000\006\000\006\000\006\000\
    \116\000\255\255\116\000\006\000\006\000\255\255\006\000\006\000\
    \006\000\188\000\193\000\255\255\188\000\193\000\186\000\004\000\
    \255\255\004\000\255\255\006\000\005\000\006\000\006\000\006\000\
    \006\000\006\000\255\255\199\000\200\000\007\000\199\000\200\000\
    \007\000\007\000\007\000\255\255\255\255\175\000\007\000\007\000\
    \175\000\007\000\007\000\007\000\255\255\255\255\255\255\255\255\
    \255\255\148\000\005\000\255\255\005\000\255\255\007\000\006\000\
    \007\000\007\000\007\000\007\000\007\000\175\000\255\255\194\000\
    \008\000\255\255\194\000\008\000\008\000\008\000\255\255\255\255\
    \255\255\008\000\008\000\255\255\008\000\008\000\008\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\006\000\255\255\006\000\
    \255\255\008\000\007\000\008\000\008\000\008\000\008\000\008\000\
    \255\255\255\255\255\255\010\000\255\255\255\255\010\000\010\000\
    \010\000\255\255\255\255\255\255\010\000\010\000\255\255\010\000\
    \010\000\010\000\255\255\255\255\255\255\255\255\255\255\175\000\
    \007\000\255\255\007\000\255\255\010\000\008\000\010\000\010\000\
    \010\000\010\000\010\000\255\255\255\255\255\255\255\255\255\255\
    \013\000\255\255\255\255\013\000\013\000\013\000\255\255\025\000\
    \255\255\013\000\013\000\255\255\013\000\013\000\013\000\255\255\
    \255\255\255\255\255\255\008\000\255\255\008\000\114\000\010\000\
    \010\000\013\000\255\255\013\000\013\000\013\000\013\000\013\000\
    \117\000\255\255\255\255\014\000\255\255\255\255\014\000\014\000\
    \014\000\194\000\115\000\255\255\014\000\014\000\255\255\014\000\
    \014\000\014\000\255\255\255\255\255\255\255\255\010\000\255\255\
    \010\000\255\255\255\255\255\255\014\000\013\000\014\000\014\000\
    \014\000\014\000\014\000\255\255\255\255\255\255\017\000\255\255\
    \255\255\017\000\017\000\017\000\205\000\148\000\255\255\017\000\
    \017\000\255\255\017\000\017\000\017\000\206\000\208\000\255\255\
    \116\000\255\255\255\255\013\000\255\255\013\000\255\255\017\000\
    \014\000\017\000\017\000\017\000\017\000\017\000\255\255\255\255\
    \255\255\021\000\255\255\255\255\021\000\021\000\021\000\255\255\
    \255\255\255\255\021\000\021\000\255\255\021\000\021\000\021\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\014\000\255\255\
    \014\000\255\255\021\000\017\000\021\000\021\000\021\000\021\000\
    \021\000\090\000\090\000\090\000\090\000\090\000\090\000\090\000\
    \090\000\090\000\090\000\175\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\090\000\090\000\090\000\090\000\090\000\090\000\
    \255\255\017\000\255\255\017\000\255\255\255\255\021\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\194\000\255\255\255\255\
    \022\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\090\000\090\000\090\000\090\000\090\000\090\000\
    \255\255\255\255\255\255\255\255\021\000\255\255\021\000\022\000\
    \022\000\255\255\022\000\022\000\022\000\022\000\255\255\255\255\
    \255\255\022\000\022\000\111\000\022\000\022\000\022\000\022\000\
    \022\000\022\000\022\000\022\000\022\000\022\000\022\000\022\000\
    \022\000\022\000\255\255\022\000\022\000\022\000\022\000\022\000\
    \255\255\255\255\111\000\023\000\255\255\255\255\023\000\023\000\
    \023\000\255\255\255\255\023\000\023\000\023\000\255\255\023\000\
    \023\000\023\000\111\000\111\000\111\000\111\000\111\000\111\000\
    \111\000\111\000\111\000\111\000\023\000\022\000\023\000\023\000\
    \023\000\023\000\023\000\165\000\165\000\165\000\165\000\165\000\
    \165\000\165\000\165\000\165\000\165\000\168\000\168\000\168\000\
    \168\000\168\000\168\000\168\000\168\000\168\000\168\000\255\255\
    \255\255\255\255\255\255\022\000\026\000\022\000\255\255\082\000\
    \023\000\082\000\082\000\082\000\082\000\082\000\082\000\082\000\
    \082\000\082\000\082\000\082\000\082\000\082\000\082\000\082\000\
    \082\000\082\000\082\000\082\000\082\000\082\000\082\000\082\000\
    \082\000\082\000\082\000\255\255\082\000\255\255\023\000\026\000\
    \023\000\026\000\026\000\026\000\026\000\026\000\026\000\026\000\
    \026\000\026\000\026\000\026\000\026\000\026\000\026\000\026\000\
    \026\000\026\000\026\000\026\000\026\000\026\000\026\000\026\000\
    \026\000\026\000\026\000\255\255\026\000\028\000\028\000\028\000\
    \028\000\028\000\028\000\028\000\028\000\028\000\028\000\028\000\
    \028\000\028\000\028\000\028\000\028\000\028\000\028\000\028\000\
    \028\000\028\000\028\000\028\000\028\000\028\000\028\000\028\000\
    \028\000\028\000\028\000\028\000\028\000\028\000\028\000\028\000\
    \028\000\028\000\028\000\028\000\255\255\028\000\028\000\028\000\
    \028\000\028\000\028\000\028\000\028\000\028\000\028\000\028\000\
    \028\000\028\000\028\000\028\000\028\000\028\000\028\000\028\000\
    \028\000\028\000\028\000\028\000\028\000\028\000\255\255\255\255\
    \255\255\255\255\028\000\255\255\028\000\028\000\028\000\028\000\
    \028\000\028\000\028\000\028\000\028\000\028\000\028\000\028\000\
    \028\000\028\000\028\000\028\000\028\000\028\000\028\000\028\000\
    \028\000\028\000\028\000\028\000\028\000\028\000\255\255\255\255\
    \255\255\255\255\028\000\255\255\028\000\028\000\028\000\028\000\
    \028\000\028\000\028\000\028\000\028\000\028\000\028\000\028\000\
    \028\000\028\000\028\000\028\000\028\000\028\000\028\000\028\000\
    \028\000\028\000\028\000\028\000\028\000\029\000\029\000\029\000\
    \029\000\029\000\029\000\029\000\029\000\029\000\029\000\029\000\
    \029\000\029\000\029\000\029\000\029\000\029\000\029\000\029\000\
    \029\000\029\000\029\000\029\000\029\000\029\000\029\000\029\000\
    \029\000\029\000\029\000\029\000\029\000\029\000\029\000\029\000\
    \029\000\029\000\029\000\029\000\255\255\029\000\029\000\029\000\
    \029\000\029\000\029\000\029\000\029\000\029\000\029\000\029\000\
    \029\000\029\000\029\000\029\000\029\000\029\000\029\000\029\000\
    \029\000\029\000\029\000\029\000\029\000\029\000\255\255\029\000\
    \255\255\255\255\029\000\255\255\029\000\029\000\029\000\029\000\
    \029\000\029\000\029\000\029\000\029\000\029\000\029\000\029\000\
    \029\000\029\000\029\000\029\000\029\000\029\000\029\000\029\000\
    \029\000\029\000\029\000\029\000\029\000\029\000\255\255\029\000\
    \255\255\255\255\029\000\255\255\029\000\029\000\029\000\029\000\
    \029\000\029\000\029\000\029\000\029\000\029\000\029\000\029\000\
    \029\000\029\000\029\000\029\000\029\000\029\000\029\000\029\000\
    \029\000\029\000\029\000\029\000\029\000\028\000\255\255\255\255\
    \255\255\255\255\255\255\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\255\255\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\102\000\102\000\102\000\102\000\102\000\
    \102\000\102\000\102\000\102\000\102\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\102\000\102\000\102\000\102\000\
    \102\000\102\000\184\000\184\000\184\000\184\000\184\000\184\000\
    \184\000\184\000\184\000\184\000\255\255\143\000\255\255\255\255\
    \143\000\255\255\255\255\255\255\255\255\255\255\030\000\030\000\
    \030\000\030\000\255\255\030\000\102\000\102\000\102\000\102\000\
    \102\000\102\000\255\255\255\255\255\255\143\000\255\255\255\255\
    \255\255\255\255\143\000\143\000\255\255\143\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\029\000\030\000\030\000\
    \030\000\030\000\030\000\031\000\031\000\031\000\031\000\031\000\
    \031\000\031\000\031\000\031\000\031\000\031\000\031\000\031\000\
    \031\000\031\000\031\000\031\000\031\000\031\000\031\000\031\000\
    \031\000\031\000\031\000\031\000\031\000\031\000\031\000\031\000\
    \031\000\031\000\031\000\031\000\031\000\031\000\031\000\031\000\
    \031\000\031\000\255\255\031\000\031\000\031\000\031\000\031\000\
    \031\000\031\000\031\000\189\000\189\000\189\000\189\000\189\000\
    \189\000\189\000\189\000\189\000\189\000\031\000\031\000\031\000\
    \031\000\031\000\031\000\031\000\110\000\110\000\143\000\255\255\
    \110\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\110\000\255\255\110\000\031\000\031\000\
    \031\000\031\000\255\255\031\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\110\000\110\000\110\000\110\000\110\000\
    \110\000\110\000\110\000\110\000\110\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\031\000\031\000\
    \031\000\031\000\031\000\030\000\255\255\255\255\255\255\255\255\
    \255\255\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \255\255\032\000\032\000\032\000\032\000\032\000\032\000\032\000\
    \032\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\032\000\032\000\032\000\032\000\032\000\
    \032\000\032\000\255\255\143\000\164\000\164\000\164\000\164\000\
    \164\000\164\000\164\000\164\000\164\000\164\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\164\000\164\000\164\000\
    \164\000\164\000\164\000\255\255\032\000\032\000\032\000\032\000\
    \255\255\032\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\164\000\164\000\164\000\
    \164\000\164\000\164\000\031\000\032\000\032\000\032\000\032\000\
    \032\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \255\255\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\255\255\255\255\110\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\255\255\255\255\255\255\255\255\255\255\034\000\
    \255\255\255\255\034\000\034\000\034\000\255\255\255\255\255\255\
    \034\000\034\000\255\255\034\000\034\000\034\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\033\000\033\000\033\000\033\000\
    \034\000\033\000\034\000\034\000\034\000\034\000\034\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\033\000\033\000\033\000\033\000\
    \033\000\032\000\255\255\255\255\034\000\034\000\255\255\034\000\
    \034\000\034\000\034\000\034\000\034\000\034\000\034\000\034\000\
    \034\000\034\000\034\000\034\000\034\000\034\000\034\000\034\000\
    \034\000\034\000\034\000\034\000\034\000\034\000\034\000\034\000\
    \034\000\255\255\034\000\035\000\034\000\255\255\035\000\035\000\
    \035\000\255\255\255\255\255\255\035\000\035\000\255\255\035\000\
    \035\000\035\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\035\000\255\255\035\000\035\000\
    \035\000\035\000\035\000\255\255\196\000\255\255\196\000\196\000\
    \196\000\196\000\196\000\196\000\196\000\196\000\196\000\196\000\
    \196\000\196\000\196\000\196\000\196\000\196\000\196\000\196\000\
    \196\000\196\000\196\000\196\000\196\000\196\000\196\000\196\000\
    \035\000\035\000\196\000\035\000\035\000\035\000\035\000\035\000\
    \035\000\035\000\035\000\035\000\035\000\035\000\035\000\035\000\
    \035\000\035\000\035\000\035\000\035\000\035\000\035\000\035\000\
    \035\000\035\000\035\000\035\000\035\000\255\255\035\000\255\255\
    \035\000\033\000\255\255\255\255\255\255\034\000\034\000\034\000\
    \034\000\034\000\034\000\034\000\034\000\034\000\034\000\034\000\
    \034\000\034\000\034\000\034\000\034\000\034\000\034\000\034\000\
    \034\000\034\000\034\000\034\000\034\000\255\255\034\000\034\000\
    \034\000\034\000\034\000\034\000\034\000\034\000\149\000\255\255\
    \149\000\149\000\149\000\149\000\149\000\149\000\149\000\149\000\
    \149\000\149\000\149\000\149\000\149\000\149\000\149\000\149\000\
    \149\000\149\000\149\000\149\000\149\000\149\000\149\000\149\000\
    \149\000\149\000\156\000\149\000\156\000\156\000\156\000\156\000\
    \156\000\156\000\156\000\156\000\156\000\156\000\156\000\156\000\
    \156\000\156\000\156\000\156\000\156\000\156\000\156\000\156\000\
    \156\000\156\000\156\000\156\000\156\000\156\000\255\255\156\000\
    \255\255\035\000\035\000\035\000\035\000\035\000\035\000\035\000\
    \035\000\035\000\035\000\035\000\035\000\035\000\035\000\035\000\
    \035\000\035\000\035\000\035\000\035\000\035\000\035\000\035\000\
    \035\000\255\255\035\000\035\000\035\000\035\000\035\000\035\000\
    \035\000\035\000\036\000\036\000\036\000\036\000\036\000\036\000\
    \036\000\036\000\036\000\036\000\036\000\036\000\036\000\036\000\
    \036\000\036\000\036\000\036\000\036\000\036\000\036\000\036\000\
    \036\000\036\000\036\000\036\000\036\000\036\000\036\000\036\000\
    \036\000\036\000\036\000\036\000\036\000\036\000\036\000\036\000\
    \036\000\255\255\036\000\036\000\036\000\036\000\036\000\036\000\
    \036\000\036\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\036\000\036\000\036\000\036\000\
    \036\000\036\000\036\000\255\255\255\255\255\255\255\255\255\255\
    \037\000\255\255\255\255\037\000\037\000\037\000\255\255\255\255\
    \255\255\037\000\037\000\255\255\037\000\037\000\037\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\036\000\036\000\036\000\
    \036\000\037\000\036\000\037\000\037\000\037\000\037\000\037\000\
    \255\255\255\255\255\255\255\255\255\255\051\000\255\255\255\255\
    \051\000\051\000\051\000\255\255\255\255\255\255\051\000\051\000\
    \255\255\051\000\051\000\051\000\255\255\036\000\036\000\036\000\
    \036\000\036\000\255\255\255\255\037\000\037\000\051\000\255\255\
    \051\000\051\000\051\000\051\000\051\000\255\255\255\255\255\255\
    \052\000\255\255\255\255\052\000\052\000\052\000\255\255\255\255\
    \255\255\052\000\052\000\255\255\052\000\052\000\052\000\255\255\
    \157\000\255\255\157\000\037\000\037\000\037\000\255\255\157\000\
    \255\255\052\000\051\000\052\000\052\000\052\000\052\000\052\000\
    \157\000\157\000\157\000\157\000\157\000\157\000\157\000\157\000\
    \157\000\157\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \051\000\255\255\051\000\255\255\255\255\052\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\157\000\255\255\255\255\255\255\
    \255\255\255\255\157\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\052\000\255\255\052\000\157\000\255\255\
    \255\255\255\255\157\000\255\255\157\000\255\255\255\255\255\255\
    \157\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\036\000\053\000\053\000\053\000\053\000\053\000\
    \053\000\053\000\053\000\053\000\053\000\053\000\053\000\053\000\
    \053\000\053\000\053\000\053\000\053\000\053\000\053\000\053\000\
    \053\000\053\000\053\000\053\000\053\000\053\000\053\000\053\000\
    \053\000\053\000\053\000\053\000\053\000\053\000\053\000\053\000\
    \053\000\053\000\255\255\053\000\053\000\053\000\053\000\053\000\
    \053\000\053\000\053\000\171\000\171\000\171\000\171\000\171\000\
    \171\000\171\000\171\000\171\000\171\000\053\000\053\000\053\000\
    \053\000\053\000\053\000\053\000\171\000\171\000\171\000\171\000\
    \171\000\171\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\053\000\053\000\
    \053\000\053\000\255\255\053\000\171\000\171\000\171\000\171\000\
    \171\000\171\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\053\000\053\000\
    \053\000\053\000\053\000\054\000\054\000\054\000\054\000\054\000\
    \054\000\054\000\054\000\054\000\054\000\054\000\054\000\054\000\
    \054\000\054\000\054\000\054\000\054\000\054\000\054\000\054\000\
    \054\000\054\000\054\000\054\000\054\000\054\000\054\000\054\000\
    \054\000\054\000\054\000\054\000\054\000\054\000\054\000\054\000\
    \054\000\054\000\255\255\054\000\054\000\054\000\054\000\054\000\
    \054\000\054\000\054\000\183\000\183\000\183\000\183\000\183\000\
    \183\000\183\000\183\000\183\000\183\000\054\000\054\000\054\000\
    \054\000\054\000\054\000\054\000\183\000\183\000\183\000\183\000\
    \183\000\183\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\054\000\054\000\
    \054\000\054\000\255\255\054\000\183\000\183\000\183\000\183\000\
    \183\000\183\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\054\000\054\000\
    \054\000\054\000\054\000\053\000\255\255\255\255\255\255\255\255\
    \255\255\057\000\057\000\057\000\057\000\057\000\057\000\057\000\
    \057\000\057\000\057\000\057\000\057\000\057\000\057\000\057\000\
    \057\000\057\000\057\000\057\000\057\000\057\000\057\000\057\000\
    \057\000\057\000\057\000\057\000\057\000\057\000\057\000\057\000\
    \057\000\057\000\057\000\057\000\057\000\057\000\057\000\057\000\
    \255\255\057\000\057\000\057\000\057\000\057\000\057\000\057\000\
    \057\000\191\000\191\000\191\000\191\000\191\000\191\000\191\000\
    \191\000\191\000\191\000\057\000\057\000\057\000\057\000\057\000\
    \057\000\057\000\191\000\191\000\191\000\191\000\191\000\191\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\057\000\057\000\057\000\057\000\
    \255\255\057\000\191\000\191\000\191\000\191\000\191\000\191\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\054\000\057\000\057\000\057\000\057\000\
    \057\000\058\000\058\000\058\000\058\000\058\000\058\000\058\000\
    \058\000\058\000\058\000\058\000\058\000\058\000\058\000\058\000\
    \058\000\058\000\058\000\058\000\058\000\058\000\058\000\058\000\
    \058\000\058\000\058\000\058\000\058\000\058\000\058\000\058\000\
    \058\000\058\000\058\000\058\000\058\000\058\000\058\000\058\000\
    \255\255\058\000\058\000\058\000\058\000\058\000\058\000\058\000\
    \058\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\058\000\058\000\058\000\058\000\058\000\
    \058\000\058\000\255\255\255\255\255\255\255\255\255\255\059\000\
    \255\255\255\255\059\000\059\000\059\000\255\255\255\255\255\255\
    \059\000\059\000\255\255\059\000\059\000\059\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\058\000\058\000\058\000\058\000\
    \059\000\058\000\059\000\059\000\059\000\059\000\059\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\058\000\058\000\058\000\058\000\
    \058\000\057\000\255\255\202\000\059\000\202\000\202\000\202\000\
    \202\000\202\000\202\000\202\000\202\000\202\000\202\000\202\000\
    \202\000\202\000\202\000\202\000\202\000\202\000\202\000\202\000\
    \202\000\202\000\202\000\202\000\202\000\202\000\202\000\255\255\
    \255\255\202\000\059\000\255\255\059\000\255\255\255\255\062\000\
    \062\000\062\000\062\000\062\000\062\000\062\000\062\000\062\000\
    \062\000\062\000\062\000\062\000\062\000\062\000\062\000\062\000\
    \062\000\062\000\062\000\062\000\062\000\062\000\062\000\062\000\
    \062\000\062\000\062\000\062\000\062\000\062\000\062\000\062\000\
    \062\000\062\000\062\000\062\000\062\000\062\000\255\255\062\000\
    \062\000\062\000\062\000\062\000\062\000\062\000\062\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\062\000\062\000\062\000\062\000\062\000\062\000\062\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\058\000\062\000\062\000\062\000\062\000\255\255\062\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\062\000\062\000\062\000\062\000\062\000\063\000\
    \063\000\063\000\063\000\063\000\063\000\063\000\063\000\063\000\
    \063\000\063\000\063\000\063\000\063\000\063\000\063\000\063\000\
    \063\000\063\000\063\000\063\000\063\000\063\000\063\000\063\000\
    \063\000\063\000\063\000\063\000\063\000\063\000\063\000\063\000\
    \063\000\063\000\063\000\063\000\063\000\063\000\255\255\063\000\
    \063\000\063\000\063\000\063\000\063\000\063\000\063\000\063\000\
    \063\000\063\000\063\000\063\000\063\000\063\000\063\000\063\000\
    \063\000\063\000\063\000\063\000\063\000\063\000\063\000\063\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\063\000\063\000\063\000\063\000\255\255\063\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\063\000\063\000\063\000\063\000\063\000\062\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\064\000\064\000\064\000\064\000\064\000\064\000\064\000\
    \064\000\064\000\064\000\064\000\064\000\064\000\064\000\064\000\
    \064\000\064\000\064\000\064\000\064\000\064\000\064\000\064\000\
    \064\000\064\000\064\000\064\000\064\000\064\000\064\000\064\000\
    \064\000\064\000\064\000\064\000\064\000\064\000\064\000\064\000\
    \255\255\064\000\064\000\064\000\064\000\064\000\064\000\064\000\
    \064\000\064\000\064\000\064\000\064\000\064\000\064\000\064\000\
    \064\000\064\000\064\000\064\000\064\000\064\000\064\000\064\000\
    \064\000\064\000\255\255\255\255\255\255\255\255\064\000\255\255\
    \064\000\064\000\064\000\064\000\064\000\064\000\064\000\064\000\
    \064\000\064\000\064\000\064\000\064\000\064\000\064\000\064\000\
    \064\000\064\000\064\000\064\000\064\000\064\000\064\000\064\000\
    \064\000\064\000\255\255\255\255\255\255\255\255\064\000\063\000\
    \064\000\064\000\064\000\064\000\064\000\064\000\064\000\064\000\
    \064\000\064\000\064\000\064\000\064\000\064\000\064\000\064\000\
    \064\000\064\000\064\000\064\000\064\000\064\000\064\000\064\000\
    \064\000\065\000\065\000\065\000\065\000\065\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\065\000\065\000\
    \065\000\065\000\065\000\065\000\065\000\065\000\065\000\065\000\
    \255\255\065\000\065\000\065\000\065\000\065\000\065\000\065\000\
    \065\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\065\000\065\000\065\000\065\000\065\000\
    \065\000\065\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\065\000\065\000\065\000\065\000\
    \255\255\065\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\065\000\065\000\065\000\065\000\
    \065\000\064\000\255\255\255\255\255\255\255\255\255\255\066\000\
    \066\000\066\000\066\000\066\000\066\000\066\000\066\000\066\000\
    \066\000\066\000\066\000\066\000\066\000\066\000\066\000\066\000\
    \066\000\066\000\066\000\066\000\066\000\066\000\066\000\066\000\
    \066\000\066\000\066\000\066\000\066\000\066\000\066\000\066\000\
    \066\000\066\000\066\000\066\000\066\000\066\000\255\255\066\000\
    \066\000\066\000\066\000\066\000\066\000\066\000\066\000\066\000\
    \066\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\066\000\066\000\066\000\066\000\066\000\066\000\066\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\066\000\066\000\066\000\066\000\255\255\066\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\065\000\066\000\066\000\066\000\066\000\066\000\067\000\
    \067\000\067\000\067\000\067\000\067\000\067\000\067\000\067\000\
    \067\000\067\000\067\000\067\000\067\000\067\000\067\000\067\000\
    \067\000\067\000\067\000\067\000\067\000\067\000\067\000\067\000\
    \067\000\067\000\067\000\067\000\067\000\067\000\067\000\067\000\
    \067\000\067\000\067\000\067\000\067\000\067\000\255\255\067\000\
    \067\000\067\000\067\000\067\000\067\000\067\000\067\000\067\000\
    \067\000\067\000\067\000\067\000\067\000\067\000\067\000\255\255\
    \255\255\067\000\067\000\067\000\067\000\067\000\067\000\067\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\067\000\067\000\067\000\067\000\255\255\067\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\067\000\067\000\067\000\067\000\067\000\066\000\
    \255\255\255\255\255\255\255\255\255\255\068\000\068\000\068\000\
    \068\000\068\000\068\000\068\000\068\000\068\000\068\000\068\000\
    \068\000\068\000\068\000\068\000\068\000\068\000\068\000\068\000\
    \068\000\068\000\068\000\068\000\068\000\068\000\068\000\068\000\
    \068\000\068\000\068\000\068\000\068\000\068\000\068\000\068\000\
    \068\000\068\000\068\000\068\000\255\255\068\000\068\000\068\000\
    \068\000\068\000\068\000\068\000\068\000\068\000\068\000\068\000\
    \068\000\068\000\068\000\068\000\068\000\068\000\068\000\068\000\
    \068\000\068\000\068\000\068\000\068\000\068\000\068\000\068\000\
    \068\000\068\000\068\000\068\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \068\000\068\000\068\000\068\000\255\255\068\000\068\000\068\000\
    \068\000\068\000\068\000\068\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\067\000\
    \068\000\068\000\068\000\068\000\068\000\069\000\069\000\069\000\
    \069\000\069\000\069\000\069\000\069\000\069\000\069\000\069\000\
    \069\000\069\000\069\000\069\000\069\000\069\000\069\000\069\000\
    \069\000\069\000\069\000\069\000\069\000\069\000\069\000\069\000\
    \069\000\069\000\069\000\069\000\069\000\069\000\069\000\069\000\
    \069\000\069\000\069\000\069\000\255\255\069\000\069\000\069\000\
    \069\000\069\000\069\000\069\000\069\000\069\000\069\000\069\000\
    \069\000\069\000\069\000\069\000\069\000\069\000\069\000\069\000\
    \069\000\069\000\069\000\069\000\069\000\069\000\069\000\069\000\
    \069\000\069\000\069\000\069\000\069\000\069\000\069\000\069\000\
    \069\000\069\000\069\000\069\000\069\000\069\000\069\000\069\000\
    \069\000\069\000\069\000\069\000\069\000\069\000\069\000\069\000\
    \069\000\069\000\069\000\069\000\069\000\069\000\069\000\069\000\
    \069\000\069\000\069\000\069\000\069\000\069\000\069\000\069\000\
    \069\000\069\000\069\000\069\000\069\000\069\000\069\000\069\000\
    \069\000\069\000\069\000\069\000\069\000\069\000\069\000\069\000\
    \069\000\069\000\069\000\069\000\069\000\068\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\070\000\070\000\
    \070\000\070\000\070\000\070\000\070\000\070\000\070\000\070\000\
    \070\000\070\000\070\000\070\000\070\000\070\000\070\000\070\000\
    \070\000\070\000\070\000\070\000\070\000\070\000\070\000\070\000\
    \070\000\070\000\070\000\070\000\070\000\070\000\070\000\070\000\
    \070\000\070\000\070\000\070\000\070\000\069\000\070\000\070\000\
    \070\000\070\000\070\000\070\000\070\000\070\000\070\000\070\000\
    \070\000\070\000\070\000\070\000\070\000\070\000\070\000\070\000\
    \070\000\070\000\070\000\070\000\070\000\070\000\070\000\070\000\
    \070\000\070\000\070\000\070\000\070\000\070\000\070\000\070\000\
    \070\000\070\000\070\000\070\000\070\000\070\000\070\000\070\000\
    \070\000\070\000\070\000\070\000\070\000\070\000\070\000\070\000\
    \070\000\070\000\070\000\070\000\070\000\070\000\070\000\070\000\
    \070\000\070\000\070\000\070\000\070\000\070\000\070\000\070\000\
    \070\000\070\000\070\000\070\000\070\000\070\000\070\000\070\000\
    \070\000\070\000\070\000\070\000\070\000\070\000\070\000\070\000\
    \070\000\070\000\070\000\070\000\070\000\070\000\071\000\071\000\
    \071\000\071\000\071\000\071\000\071\000\071\000\071\000\071\000\
    \071\000\071\000\071\000\071\000\071\000\071\000\071\000\071\000\
    \071\000\071\000\071\000\071\000\071\000\071\000\071\000\071\000\
    \071\000\071\000\071\000\071\000\071\000\071\000\071\000\071\000\
    \071\000\071\000\071\000\071\000\071\000\255\255\071\000\071\000\
    \071\000\071\000\071\000\071\000\071\000\071\000\071\000\071\000\
    \071\000\071\000\071\000\071\000\071\000\071\000\071\000\071\000\
    \071\000\071\000\071\000\071\000\071\000\071\000\071\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\071\000\071\000\071\000\071\000\255\255\071\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\071\000\071\000\071\000\071\000\071\000\070\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \072\000\072\000\072\000\072\000\072\000\072\000\072\000\072\000\
    \072\000\072\000\072\000\072\000\072\000\072\000\072\000\072\000\
    \072\000\072\000\072\000\072\000\072\000\072\000\072\000\072\000\
    \072\000\072\000\072\000\072\000\072\000\072\000\072\000\072\000\
    \072\000\072\000\072\000\072\000\072\000\072\000\072\000\255\255\
    \072\000\072\000\072\000\072\000\072\000\072\000\072\000\072\000\
    \072\000\072\000\072\000\072\000\072\000\072\000\072\000\072\000\
    \072\000\072\000\072\000\072\000\072\000\072\000\072\000\072\000\
    \072\000\255\255\255\255\255\255\255\255\255\255\255\255\072\000\
    \072\000\072\000\072\000\072\000\072\000\072\000\072\000\072\000\
    \072\000\072\000\072\000\072\000\072\000\072\000\072\000\072\000\
    \072\000\072\000\072\000\072\000\072\000\072\000\072\000\072\000\
    \072\000\255\255\255\255\255\255\255\255\255\255\071\000\072\000\
    \072\000\072\000\072\000\072\000\072\000\072\000\072\000\072\000\
    \072\000\072\000\072\000\072\000\072\000\072\000\072\000\072\000\
    \072\000\072\000\072\000\072\000\072\000\072\000\072\000\072\000\
    \074\000\074\000\074\000\074\000\074\000\074\000\074\000\074\000\
    \074\000\074\000\074\000\074\000\074\000\074\000\074\000\074\000\
    \074\000\074\000\074\000\074\000\074\000\074\000\074\000\074\000\
    \074\000\074\000\074\000\074\000\074\000\074\000\074\000\074\000\
    \074\000\074\000\074\000\074\000\074\000\074\000\074\000\255\255\
    \074\000\074\000\074\000\074\000\074\000\074\000\074\000\074\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\074\000\074\000\074\000\074\000\074\000\074\000\
    \074\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\074\000\074\000\074\000\074\000\255\255\
    \074\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\074\000\074\000\074\000\074\000\074\000\
    \072\000\255\255\255\255\255\255\255\255\255\255\075\000\075\000\
    \075\000\075\000\075\000\075\000\075\000\075\000\075\000\075\000\
    \075\000\075\000\075\000\075\000\075\000\075\000\075\000\075\000\
    \075\000\075\000\075\000\075\000\075\000\075\000\075\000\075\000\
    \075\000\075\000\075\000\075\000\075\000\075\000\075\000\075\000\
    \075\000\075\000\075\000\075\000\075\000\255\255\075\000\075\000\
    \075\000\075\000\075\000\075\000\075\000\075\000\075\000\075\000\
    \075\000\075\000\075\000\075\000\075\000\075\000\075\000\075\000\
    \075\000\075\000\075\000\075\000\075\000\075\000\075\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\075\000\075\000\075\000\075\000\255\255\075\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \074\000\075\000\075\000\075\000\075\000\075\000\076\000\076\000\
    \076\000\076\000\076\000\076\000\076\000\076\000\076\000\076\000\
    \076\000\076\000\076\000\076\000\076\000\076\000\076\000\076\000\
    \076\000\076\000\076\000\076\000\076\000\076\000\076\000\076\000\
    \076\000\076\000\076\000\076\000\076\000\076\000\076\000\076\000\
    \076\000\076\000\076\000\076\000\076\000\255\255\076\000\076\000\
    \076\000\076\000\076\000\076\000\076\000\076\000\076\000\076\000\
    \076\000\076\000\076\000\076\000\076\000\076\000\255\255\255\255\
    \076\000\076\000\076\000\076\000\076\000\076\000\076\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\076\000\076\000\076\000\
    \076\000\076\000\076\000\076\000\076\000\076\000\076\000\076\000\
    \076\000\076\000\076\000\076\000\076\000\076\000\076\000\076\000\
    \076\000\076\000\076\000\076\000\076\000\076\000\076\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\076\000\076\000\076\000\
    \076\000\076\000\076\000\076\000\076\000\076\000\076\000\076\000\
    \076\000\076\000\076\000\076\000\076\000\076\000\076\000\076\000\
    \076\000\076\000\076\000\076\000\076\000\076\000\075\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \077\000\077\000\077\000\077\000\077\000\077\000\077\000\077\000\
    \077\000\077\000\077\000\077\000\077\000\077\000\077\000\077\000\
    \077\000\077\000\077\000\077\000\077\000\077\000\077\000\077\000\
    \077\000\077\000\077\000\077\000\077\000\077\000\077\000\077\000\
    \077\000\077\000\077\000\077\000\077\000\077\000\077\000\255\255\
    \077\000\077\000\077\000\077\000\077\000\077\000\077\000\077\000\
    \077\000\077\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\077\000\077\000\077\000\077\000\077\000\077\000\
    \077\000\255\255\255\255\255\255\255\255\255\255\255\255\077\000\
    \077\000\077\000\077\000\077\000\077\000\077\000\077\000\077\000\
    \077\000\077\000\077\000\077\000\077\000\077\000\077\000\077\000\
    \077\000\077\000\077\000\077\000\077\000\077\000\077\000\077\000\
    \077\000\255\255\255\255\255\255\255\255\255\255\076\000\077\000\
    \077\000\077\000\077\000\077\000\077\000\077\000\077\000\077\000\
    \077\000\077\000\077\000\077\000\077\000\077\000\077\000\077\000\
    \077\000\077\000\077\000\077\000\077\000\077\000\077\000\077\000\
    \078\000\078\000\078\000\078\000\078\000\078\000\078\000\078\000\
    \078\000\078\000\078\000\078\000\078\000\078\000\078\000\078\000\
    \078\000\078\000\078\000\078\000\078\000\078\000\078\000\078\000\
    \078\000\078\000\078\000\078\000\078\000\078\000\078\000\078\000\
    \078\000\078\000\078\000\078\000\078\000\078\000\078\000\255\255\
    \078\000\078\000\078\000\078\000\078\000\078\000\078\000\078\000\
    \078\000\078\000\078\000\078\000\078\000\078\000\078\000\078\000\
    \078\000\078\000\078\000\078\000\078\000\078\000\078\000\078\000\
    \078\000\255\255\255\255\255\255\255\255\255\255\255\255\078\000\
    \078\000\078\000\078\000\078\000\078\000\078\000\078\000\078\000\
    \078\000\078\000\078\000\078\000\078\000\078\000\078\000\078\000\
    \078\000\078\000\078\000\078\000\078\000\078\000\078\000\078\000\
    \078\000\255\255\255\255\255\255\255\255\255\255\255\255\078\000\
    \078\000\078\000\078\000\078\000\078\000\078\000\078\000\078\000\
    \078\000\078\000\078\000\078\000\078\000\078\000\078\000\078\000\
    \078\000\078\000\078\000\078\000\078\000\078\000\078\000\078\000\
    \077\000\083\000\107\000\083\000\255\255\107\000\107\000\107\000\
    \083\000\255\255\255\255\107\000\107\000\255\255\107\000\107\000\
    \107\000\083\000\083\000\083\000\083\000\083\000\083\000\083\000\
    \083\000\083\000\083\000\107\000\255\255\107\000\107\000\107\000\
    \107\000\107\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\109\000\255\255\109\000\109\000\109\000\109\000\255\255\
    \255\255\255\255\109\000\109\000\255\255\109\000\109\000\109\000\
    \255\255\255\255\255\255\255\255\255\255\083\000\255\255\107\000\
    \255\255\255\255\109\000\083\000\109\000\109\000\109\000\109\000\
    \109\000\255\255\255\255\255\255\255\255\255\255\255\255\083\000\
    \083\000\255\255\255\255\083\000\255\255\083\000\255\255\120\000\
    \255\255\083\000\120\000\120\000\120\000\107\000\255\255\107\000\
    \120\000\120\000\255\255\120\000\120\000\120\000\109\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \120\000\255\255\120\000\120\000\120\000\120\000\120\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\121\000\255\255\
    \078\000\121\000\121\000\121\000\109\000\255\255\109\000\121\000\
    \121\000\255\255\121\000\121\000\121\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\120\000\255\255\255\255\121\000\
    \255\255\121\000\121\000\121\000\121\000\121\000\255\255\255\255\
    \255\255\122\000\255\255\255\255\122\000\122\000\122\000\255\255\
    \255\255\255\255\122\000\122\000\255\255\122\000\122\000\122\000\
    \255\255\255\255\120\000\255\255\120\000\255\255\255\255\255\255\
    \255\255\255\255\122\000\121\000\122\000\122\000\122\000\122\000\
    \122\000\255\255\255\255\255\255\255\255\255\255\255\255\123\000\
    \255\255\255\255\123\000\123\000\123\000\255\255\255\255\255\255\
    \123\000\123\000\255\255\123\000\123\000\123\000\255\255\255\255\
    \255\255\121\000\255\255\121\000\255\255\255\255\122\000\255\255\
    \123\000\083\000\123\000\123\000\123\000\123\000\123\000\255\255\
    \255\255\255\255\128\000\255\255\255\255\128\000\128\000\128\000\
    \255\255\255\255\255\255\128\000\128\000\255\255\128\000\128\000\
    \128\000\255\255\255\255\255\255\122\000\255\255\122\000\255\255\
    \255\255\255\255\255\255\128\000\123\000\128\000\128\000\128\000\
    \128\000\128\000\255\255\255\255\255\255\138\000\255\255\255\255\
    \138\000\138\000\138\000\255\255\255\255\255\255\138\000\138\000\
    \255\255\138\000\138\000\138\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\123\000\255\255\123\000\255\255\138\000\128\000\
    \138\000\138\000\138\000\138\000\138\000\255\255\255\255\255\255\
    \139\000\255\255\255\255\139\000\139\000\139\000\255\255\255\255\
    \255\255\139\000\139\000\255\255\139\000\139\000\139\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\128\000\255\255\128\000\
    \255\255\139\000\138\000\139\000\139\000\139\000\139\000\139\000\
    \255\255\255\255\255\255\140\000\255\255\255\255\140\000\140\000\
    \140\000\255\255\255\255\255\255\140\000\140\000\255\255\140\000\
    \140\000\140\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \138\000\255\255\138\000\255\255\140\000\139\000\140\000\140\000\
    \140\000\140\000\140\000\255\255\255\255\255\255\141\000\255\255\
    \255\255\141\000\141\000\141\000\255\255\255\255\255\255\141\000\
    \141\000\255\255\141\000\141\000\141\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\139\000\255\255\139\000\255\255\141\000\
    \140\000\141\000\141\000\141\000\141\000\141\000\255\255\255\255\
    \255\255\142\000\255\255\255\255\142\000\142\000\142\000\255\255\
    \255\255\255\255\142\000\142\000\255\255\142\000\142\000\142\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\140\000\255\255\
    \140\000\255\255\142\000\141\000\142\000\142\000\142\000\142\000\
    \142\000\255\255\180\000\255\255\255\255\180\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \180\000\141\000\180\000\141\000\255\255\255\255\142\000\180\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \180\000\180\000\180\000\180\000\180\000\180\000\180\000\180\000\
    \180\000\180\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\142\000\255\255\142\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\180\000\255\255\255\255\255\255\
    \255\255\255\255\180\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\180\000\255\255\
    \255\255\255\255\180\000\255\255\180\000\255\255\255\255\255\255\
    \180\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \180\000";
  Lexing.lex_base_code =
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\010\000\036\000\
    \012\000\000\000\000\000\000\000\002\000\000\000\027\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\001\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\002\000\004\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000";
  Lexing.lex_backtrk_code =
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\039\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000";
  Lexing.lex_default_code =
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\019\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000";
  Lexing.lex_trans_code =
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\001\000\000\000\036\000\036\000\000\000\036\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \001\000\000\000\000\000\001\000\022\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\007\000\001\000\000\000\000\000\
    \004\000\004\000\004\000\004\000\004\000\004\000\004\000\004\000\
    \004\000\004\000\004\000\004\000\004\000\004\000\004\000\004\000\
    \004\000\004\000\004\000\004\000\001\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\004\000\004\000\004\000\004\000\
    \004\000\004\000\004\000\004\000\004\000\004\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000";
  Lexing.lex_check_code =
   "\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\022\000\115\000\180\000\187\000\115\000\188\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \022\000\255\255\115\000\000\000\116\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\110\000\111\000\255\255\255\255\
    \022\000\022\000\022\000\022\000\022\000\022\000\022\000\022\000\
    \022\000\022\000\110\000\110\000\110\000\110\000\110\000\110\000\
    \110\000\110\000\110\000\110\000\111\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\111\000\111\000\111\000\111\000\
    \111\000\111\000\111\000\111\000\111\000\111\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \115\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255";
  Lexing.lex_code =
   "\255\004\255\255\005\255\255\007\255\006\255\255\003\255\000\004\
    \001\005\255\007\255\255\006\255\007\255\255\000\004\001\005\003\
    \006\002\007\255\001\255\255\000\001\255";
}

let rec token state lexbuf =
  lexbuf.Lexing.lex_mem <- Array.make 8 (-1); __ocaml_lex_token_rec state lexbuf 0
and __ocaml_lex_token_rec state lexbuf __ocaml_lex_state =
  match Lexing.new_engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 301 "src/ocaml/typer/preprocess/lexer_raw.mll"
                 (
      match state.preprocessor with
      | None ->
        fail (Illegal_character (Lexing.lexeme_char lexbuf 0))
              (Location.curr lexbuf)
      | Some _ ->
        update_loc lexbuf None 1 false 0;
        token state lexbuf )
# 1932 "src/ocaml/typer/lexer_raw.ml"

  | 1 ->
# 310 "src/ocaml/typer/preprocess/lexer_raw.mll"
      ( update_loc lexbuf None 1 false 0;
        match state.preprocessor with
        | None -> token state lexbuf
        | Some _ -> return EOL
      )
# 1941 "src/ocaml/typer/lexer_raw.ml"

  | 2 ->
# 316 "src/ocaml/typer/preprocess/lexer_raw.mll"
      ( token state lexbuf )
# 1946 "src/ocaml/typer/lexer_raw.ml"

  | 3 ->
# 318 "src/ocaml/typer/preprocess/lexer_raw.mll"
      ( return DOTLESS )
# 1951 "src/ocaml/typer/lexer_raw.ml"

  | 4 ->
# 320 "src/ocaml/typer/preprocess/lexer_raw.mll"
      ( return (keyword_or state (Lexing.lexeme lexbuf) (INFIXOP0 ">.")) )
# 1956 "src/ocaml/typer/lexer_raw.ml"

  | 5 ->
# 322 "src/ocaml/typer/preprocess/lexer_raw.mll"
      ( return (keyword_or state (Lexing.lexeme lexbuf) DOTTILDE) )
# 1961 "src/ocaml/typer/lexer_raw.ml"

  | 6 ->
# 324 "src/ocaml/typer/preprocess/lexer_raw.mll"
      ( return UNDERSCORE )
# 1966 "src/ocaml/typer/lexer_raw.ml"

  | 7 ->
# 326 "src/ocaml/typer/preprocess/lexer_raw.mll"
      ( return TILDE )
# 1971 "src/ocaml/typer/lexer_raw.ml"

  | 8 ->
# 328 "src/ocaml/typer/preprocess/lexer_raw.mll"
      ( lABEL (get_label_name lexbuf) )
# 1976 "src/ocaml/typer/lexer_raw.ml"

  | 9 ->
# 330 "src/ocaml/typer/preprocess/lexer_raw.mll"
      ( warn_latin1 lexbuf; lABEL (get_label_name lexbuf) )
# 1981 "src/ocaml/typer/lexer_raw.ml"

  | 10 ->
# 332 "src/ocaml/typer/preprocess/lexer_raw.mll"
      ( return QUESTION )
# 1986 "src/ocaml/typer/lexer_raw.ml"

  | 11 ->
# 334 "src/ocaml/typer/preprocess/lexer_raw.mll"
      ( return QUESTIONQUESTION )
# 1991 "src/ocaml/typer/lexer_raw.ml"

  | 12 ->
# 336 "src/ocaml/typer/preprocess/lexer_raw.mll"
      ( oPTLABEL (get_label_name lexbuf) )
# 1996 "src/ocaml/typer/lexer_raw.ml"

  | 13 ->
# 338 "src/ocaml/typer/preprocess/lexer_raw.mll"
      ( warn_latin1 lexbuf; oPTLABEL (get_label_name lexbuf) )
# 2001 "src/ocaml/typer/lexer_raw.ml"

  | 14 ->
# 340 "src/ocaml/typer/preprocess/lexer_raw.mll"
    ( let s = Lexing.lexeme lexbuf in
      return (try Hashtbl.find state.keywords s
              with Not_found ->
              try Hashtbl.find keyword_table s
              with Not_found ->
                LIDENT s) )
# 2011 "src/ocaml/typer/lexer_raw.ml"

  | 15 ->
# 347 "src/ocaml/typer/preprocess/lexer_raw.mll"
      ( warn_latin1 lexbuf; return (LIDENT (Lexing.lexeme lexbuf)) )
# 2016 "src/ocaml/typer/lexer_raw.ml"

  | 16 ->
# 349 "src/ocaml/typer/preprocess/lexer_raw.mll"
    ( (* Capitalized keywords for OUnit *)
      let s = Lexing.lexeme lexbuf in
      return (try Hashtbl.find state.keywords s
              with Not_found ->
              try Hashtbl.find keyword_table s
              with Not_found ->
                UIDENT s) )
# 2027 "src/ocaml/typer/lexer_raw.ml"

  | 17 ->
# 357 "src/ocaml/typer/preprocess/lexer_raw.mll"
    ( warn_latin1 lexbuf; return (UIDENT (Lexing.lexeme lexbuf)) )
# 2032 "src/ocaml/typer/lexer_raw.ml"

  | 18 ->
# 358 "src/ocaml/typer/preprocess/lexer_raw.mll"
                ( return (INT (Lexing.lexeme lexbuf, None)) )
# 2037 "src/ocaml/typer/lexer_raw.ml"

  | 19 ->
let
# 359 "src/ocaml/typer/preprocess/lexer_raw.mll"
                    lit
# 2043 "src/ocaml/typer/lexer_raw.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos (lexbuf.Lexing.lex_curr_pos + -1)
and
# 359 "src/ocaml/typer/preprocess/lexer_raw.mll"
                                              modif
# 2048 "src/ocaml/typer/lexer_raw.ml"
= Lexing.sub_lexeme_char lexbuf (lexbuf.Lexing.lex_curr_pos + -1) in
# 360 "src/ocaml/typer/preprocess/lexer_raw.mll"
    ( return (INT (lit, Some modif)) )
# 2052 "src/ocaml/typer/lexer_raw.ml"

  | 20 ->
# 362 "src/ocaml/typer/preprocess/lexer_raw.mll"
    ( return (FLOAT (Lexing.lexeme lexbuf, None)) )
# 2057 "src/ocaml/typer/lexer_raw.ml"

  | 21 ->
let
# 363 "src/ocaml/typer/preprocess/lexer_raw.mll"
                                            lit
# 2063 "src/ocaml/typer/lexer_raw.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos (lexbuf.Lexing.lex_curr_pos + -1)
and
# 363 "src/ocaml/typer/preprocess/lexer_raw.mll"
                                                                      modif
# 2068 "src/ocaml/typer/lexer_raw.ml"
= Lexing.sub_lexeme_char lexbuf (lexbuf.Lexing.lex_curr_pos + -1) in
# 364 "src/ocaml/typer/preprocess/lexer_raw.mll"
    ( return (FLOAT (lit, Some modif)) )
# 2072 "src/ocaml/typer/lexer_raw.ml"

  | 22 ->
# 366 "src/ocaml/typer/preprocess/lexer_raw.mll"
     ( fail (Invalid_literal (Lexing.lexeme lexbuf)) (Location.curr lexbuf) )
# 2077 "src/ocaml/typer/lexer_raw.ml"

  | 23 ->
# 368 "src/ocaml/typer/preprocess/lexer_raw.mll"
      ( Buffer.reset state.buffer;
        state.string_start_loc <- Location.curr lexbuf;
        string state lexbuf >>= fun () ->
        lexbuf.lex_start_p <- state.string_start_loc.Location.loc_start;
        state.string_start_loc <- Location.none;
        return (STRING (Buffer.contents state.buffer, None))
      )
# 2088 "src/ocaml/typer/lexer_raw.ml"

  | 24 ->
# 376 "src/ocaml/typer/preprocess/lexer_raw.mll"
      ( Buffer.reset state.buffer;
        let delim = Lexing.lexeme lexbuf in
        let delim = String.sub delim 1 (String.length delim - 2) in
        state.string_start_loc <- Location.curr lexbuf;
        quoted_string state delim lexbuf >>= fun () ->
        lexbuf.lex_start_p <- state.string_start_loc.Location.loc_start;
        state.string_start_loc <- Location.none;
        return (STRING (Buffer.contents state.buffer, Some delim)) )
# 2100 "src/ocaml/typer/lexer_raw.ml"

  | 25 ->
# 385 "src/ocaml/typer/preprocess/lexer_raw.mll"
    ( update_loc lexbuf None 1 false 1;
      return (CHAR (Lexing.lexeme_char lexbuf 1)) )
# 2106 "src/ocaml/typer/lexer_raw.ml"

  | 26 ->
# 388 "src/ocaml/typer/preprocess/lexer_raw.mll"
    ( return (CHAR (Lexing.lexeme_char lexbuf 1)) )
# 2111 "src/ocaml/typer/lexer_raw.ml"

  | 27 ->
# 390 "src/ocaml/typer/preprocess/lexer_raw.mll"
    ( return (CHAR (char_for_backslash (Lexing.lexeme_char lexbuf 2))) )
# 2116 "src/ocaml/typer/lexer_raw.ml"

  | 28 ->
# 392 "src/ocaml/typer/preprocess/lexer_raw.mll"
    ( return (CHAR(char_for_octal_code lexbuf 3)) )
# 2121 "src/ocaml/typer/lexer_raw.ml"

  | 29 ->
# 394 "src/ocaml/typer/preprocess/lexer_raw.mll"
    ( char_for_decimal_code state lexbuf 2 >>= fun c -> return (CHAR c) )
# 2126 "src/ocaml/typer/lexer_raw.ml"

  | 30 ->
# 396 "src/ocaml/typer/preprocess/lexer_raw.mll"
    ( return (CHAR (char_for_hexadecimal_code lexbuf 3)) )
# 2131 "src/ocaml/typer/lexer_raw.ml"

  | 31 ->
# 398 "src/ocaml/typer/preprocess/lexer_raw.mll"
      ( let l = Lexing.lexeme lexbuf in
        let esc = String.sub l 1 (String.length l - 1) in
        fail (Illegal_escape esc) (Location.curr lexbuf)
      )
# 2139 "src/ocaml/typer/lexer_raw.ml"

  | 32 ->
# 403 "src/ocaml/typer/preprocess/lexer_raw.mll"
      ( let start_loc = Location.curr lexbuf in
        state.comment_start_loc <- [start_loc];
        Buffer.reset state.buffer;
        comment state lexbuf >>= fun end_loc ->
        let s = Buffer.contents state.buffer in
        Buffer.reset state.buffer;
        return (COMMENT (s, { start_loc with
                              Location.loc_end = end_loc.Location.loc_end }))
      )
# 2152 "src/ocaml/typer/lexer_raw.ml"

  | 33 ->
# 413 "src/ocaml/typer/preprocess/lexer_raw.mll"
      ( let loc = Location.curr lexbuf in
        Location.prerr_warning loc Warnings.Comment_start;
        state.comment_start_loc <- [loc];
        Buffer.reset state.buffer;
        comment state lexbuf >>= fun end_loc ->
        let s = Buffer.contents state.buffer in
        Buffer.reset state.buffer;
        return (COMMENT (s, { loc with Location.loc_end = end_loc.Location.loc_end }))
      )
# 2165 "src/ocaml/typer/lexer_raw.ml"

  | 34 ->
# 423 "src/ocaml/typer/preprocess/lexer_raw.mll"
      ( let loc = Location.curr lexbuf in
        Location.prerr_warning loc Warnings.Comment_not_end;
        lexbuf.Lexing.lex_curr_pos <- lexbuf.Lexing.lex_curr_pos - 1;
        let curpos = lexbuf.lex_curr_p in
        lexbuf.lex_curr_p <- { curpos with pos_cnum = curpos.pos_cnum - 1 };
        return STAR
      )
# 2176 "src/ocaml/typer/lexer_raw.ml"

  | 35 ->
let
# 430 "src/ocaml/typer/preprocess/lexer_raw.mll"
                                   num
# 2182 "src/ocaml/typer/lexer_raw.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_mem.(0) lexbuf.Lexing.lex_mem.(1)
and
# 431 "src/ocaml/typer/preprocess/lexer_raw.mll"
                                            name
# 2187 "src/ocaml/typer/lexer_raw.ml"
= Lexing.sub_lexeme_opt lexbuf lexbuf.Lexing.lex_mem.(3) lexbuf.Lexing.lex_mem.(2) in
# 433 "src/ocaml/typer/preprocess/lexer_raw.mll"
      ( update_loc lexbuf name (int_of_string num) true 0;
        token state lexbuf
      )
# 2193 "src/ocaml/typer/lexer_raw.ml"

  | 36 ->
# 436 "src/ocaml/typer/preprocess/lexer_raw.mll"
         ( return SHARP )
# 2198 "src/ocaml/typer/lexer_raw.ml"

  | 37 ->
# 437 "src/ocaml/typer/preprocess/lexer_raw.mll"
         ( return AMPERSAND )
# 2203 "src/ocaml/typer/lexer_raw.ml"

  | 38 ->
# 438 "src/ocaml/typer/preprocess/lexer_raw.mll"
         ( return AMPERAMPER )
# 2208 "src/ocaml/typer/lexer_raw.ml"

  | 39 ->
# 439 "src/ocaml/typer/preprocess/lexer_raw.mll"
         ( return BACKQUOTE )
# 2213 "src/ocaml/typer/lexer_raw.ml"

  | 40 ->
# 440 "src/ocaml/typer/preprocess/lexer_raw.mll"
         ( return QUOTE )
# 2218 "src/ocaml/typer/lexer_raw.ml"

  | 41 ->
# 441 "src/ocaml/typer/preprocess/lexer_raw.mll"
         ( return LPAREN )
# 2223 "src/ocaml/typer/lexer_raw.ml"

  | 42 ->
# 442 "src/ocaml/typer/preprocess/lexer_raw.mll"
         ( return RPAREN )
# 2228 "src/ocaml/typer/lexer_raw.ml"

  | 43 ->
# 443 "src/ocaml/typer/preprocess/lexer_raw.mll"
         ( return STAR )
# 2233 "src/ocaml/typer/lexer_raw.ml"

  | 44 ->
# 444 "src/ocaml/typer/preprocess/lexer_raw.mll"
         ( return COMMA )
# 2238 "src/ocaml/typer/lexer_raw.ml"

  | 45 ->
# 445 "src/ocaml/typer/preprocess/lexer_raw.mll"
         ( return MINUSGREATER )
# 2243 "src/ocaml/typer/lexer_raw.ml"

  | 46 ->
# 446 "src/ocaml/typer/preprocess/lexer_raw.mll"
         ( return DOT )
# 2248 "src/ocaml/typer/lexer_raw.ml"

  | 47 ->
# 447 "src/ocaml/typer/preprocess/lexer_raw.mll"
         ( return DOTDOT )
# 2253 "src/ocaml/typer/lexer_raw.ml"

  | 48 ->
# 448 "src/ocaml/typer/preprocess/lexer_raw.mll"
         ( return COLON )
# 2258 "src/ocaml/typer/lexer_raw.ml"

  | 49 ->
# 449 "src/ocaml/typer/preprocess/lexer_raw.mll"
         ( return COLONCOLON )
# 2263 "src/ocaml/typer/lexer_raw.ml"

  | 50 ->
# 450 "src/ocaml/typer/preprocess/lexer_raw.mll"
         ( return COLONEQUAL )
# 2268 "src/ocaml/typer/lexer_raw.ml"

  | 51 ->
# 451 "src/ocaml/typer/preprocess/lexer_raw.mll"
         ( return COLONGREATER )
# 2273 "src/ocaml/typer/lexer_raw.ml"

  | 52 ->
# 452 "src/ocaml/typer/preprocess/lexer_raw.mll"
         ( return SEMI )
# 2278 "src/ocaml/typer/lexer_raw.ml"

  | 53 ->
# 453 "src/ocaml/typer/preprocess/lexer_raw.mll"
         ( return SEMISEMI )
# 2283 "src/ocaml/typer/lexer_raw.ml"

  | 54 ->
# 454 "src/ocaml/typer/preprocess/lexer_raw.mll"
         ( return LESS )
# 2288 "src/ocaml/typer/lexer_raw.ml"

  | 55 ->
# 455 "src/ocaml/typer/preprocess/lexer_raw.mll"
         ( return LESSMINUS )
# 2293 "src/ocaml/typer/lexer_raw.ml"

  | 56 ->
# 456 "src/ocaml/typer/preprocess/lexer_raw.mll"
         ( return EQUAL )
# 2298 "src/ocaml/typer/lexer_raw.ml"

  | 57 ->
# 457 "src/ocaml/typer/preprocess/lexer_raw.mll"
         ( return LBRACKET )
# 2303 "src/ocaml/typer/lexer_raw.ml"

  | 58 ->
# 458 "src/ocaml/typer/preprocess/lexer_raw.mll"
         ( return LBRACKETBAR )
# 2308 "src/ocaml/typer/lexer_raw.ml"

  | 59 ->
# 459 "src/ocaml/typer/preprocess/lexer_raw.mll"
         ( return LBRACKETLESS )
# 2313 "src/ocaml/typer/lexer_raw.ml"

  | 60 ->
# 460 "src/ocaml/typer/preprocess/lexer_raw.mll"
         ( return LBRACKETGREATER )
# 2318 "src/ocaml/typer/lexer_raw.ml"

  | 61 ->
# 461 "src/ocaml/typer/preprocess/lexer_raw.mll"
         ( return RBRACKET )
# 2323 "src/ocaml/typer/lexer_raw.ml"

  | 62 ->
# 462 "src/ocaml/typer/preprocess/lexer_raw.mll"
         ( return LBRACE )
# 2328 "src/ocaml/typer/lexer_raw.ml"

  | 63 ->
# 463 "src/ocaml/typer/preprocess/lexer_raw.mll"
         ( return LBRACELESS )
# 2333 "src/ocaml/typer/lexer_raw.ml"

  | 64 ->
# 464 "src/ocaml/typer/preprocess/lexer_raw.mll"
         ( return BAR )
# 2338 "src/ocaml/typer/lexer_raw.ml"

  | 65 ->
# 465 "src/ocaml/typer/preprocess/lexer_raw.mll"
         ( return BARBAR )
# 2343 "src/ocaml/typer/lexer_raw.ml"

  | 66 ->
# 466 "src/ocaml/typer/preprocess/lexer_raw.mll"
         ( return BARRBRACKET )
# 2348 "src/ocaml/typer/lexer_raw.ml"

  | 67 ->
# 467 "src/ocaml/typer/preprocess/lexer_raw.mll"
         ( return GREATER )
# 2353 "src/ocaml/typer/lexer_raw.ml"

  | 68 ->
# 468 "src/ocaml/typer/preprocess/lexer_raw.mll"
         ( return GREATERRBRACKET )
# 2358 "src/ocaml/typer/lexer_raw.ml"

  | 69 ->
# 469 "src/ocaml/typer/preprocess/lexer_raw.mll"
         ( return RBRACE )
# 2363 "src/ocaml/typer/lexer_raw.ml"

  | 70 ->
# 470 "src/ocaml/typer/preprocess/lexer_raw.mll"
         ( return GREATERRBRACE )
# 2368 "src/ocaml/typer/lexer_raw.ml"

  | 71 ->
# 471 "src/ocaml/typer/preprocess/lexer_raw.mll"
         ( return LBRACKETAT )
# 2373 "src/ocaml/typer/lexer_raw.ml"

  | 72 ->
# 472 "src/ocaml/typer/preprocess/lexer_raw.mll"
           ( return LBRACKETATAT )
# 2378 "src/ocaml/typer/lexer_raw.ml"

  | 73 ->
# 473 "src/ocaml/typer/preprocess/lexer_raw.mll"
           ( return LBRACKETATATAT )
# 2383 "src/ocaml/typer/lexer_raw.ml"

  | 74 ->
# 474 "src/ocaml/typer/preprocess/lexer_raw.mll"
         ( return LBRACKETPERCENT )
# 2388 "src/ocaml/typer/lexer_raw.ml"

  | 75 ->
# 475 "src/ocaml/typer/preprocess/lexer_raw.mll"
          ( return LBRACKETPERCENTPERCENT )
# 2393 "src/ocaml/typer/lexer_raw.ml"

  | 76 ->
# 476 "src/ocaml/typer/preprocess/lexer_raw.mll"
         ( return BANG )
# 2398 "src/ocaml/typer/lexer_raw.ml"

  | 77 ->
# 477 "src/ocaml/typer/preprocess/lexer_raw.mll"
         ( return (INFIXOP0 "!=") )
# 2403 "src/ocaml/typer/lexer_raw.ml"

  | 78 ->
# 478 "src/ocaml/typer/preprocess/lexer_raw.mll"
         ( return PLUS )
# 2408 "src/ocaml/typer/lexer_raw.ml"

  | 79 ->
# 479 "src/ocaml/typer/preprocess/lexer_raw.mll"
         ( return PLUSDOT )
# 2413 "src/ocaml/typer/lexer_raw.ml"

  | 80 ->
# 480 "src/ocaml/typer/preprocess/lexer_raw.mll"
         ( return PLUSEQ )
# 2418 "src/ocaml/typer/lexer_raw.ml"

  | 81 ->
# 481 "src/ocaml/typer/preprocess/lexer_raw.mll"
         ( return MINUS )
# 2423 "src/ocaml/typer/lexer_raw.ml"

  | 82 ->
# 482 "src/ocaml/typer/preprocess/lexer_raw.mll"
         ( return MINUSDOT )
# 2428 "src/ocaml/typer/lexer_raw.ml"

  | 83 ->
# 485 "src/ocaml/typer/preprocess/lexer_raw.mll"
            ( return (PREFIXOP(Lexing.lexeme lexbuf)) )
# 2433 "src/ocaml/typer/lexer_raw.ml"

  | 84 ->
# 487 "src/ocaml/typer/preprocess/lexer_raw.mll"
            ( return (PREFIXOP(Lexing.lexeme lexbuf)) )
# 2438 "src/ocaml/typer/lexer_raw.ml"

  | 85 ->
# 489 "src/ocaml/typer/preprocess/lexer_raw.mll"
            ( return (keyword_or state (Lexing.lexeme lexbuf)
                       (INFIXOP0(Lexing.lexeme lexbuf))) )
# 2444 "src/ocaml/typer/lexer_raw.ml"

  | 86 ->
# 492 "src/ocaml/typer/preprocess/lexer_raw.mll"
            ( return (INFIXOP1(Lexing.lexeme lexbuf)) )
# 2449 "src/ocaml/typer/lexer_raw.ml"

  | 87 ->
# 494 "src/ocaml/typer/preprocess/lexer_raw.mll"
            ( return (INFIXOP2(Lexing.lexeme lexbuf)) )
# 2454 "src/ocaml/typer/lexer_raw.ml"

  | 88 ->
# 496 "src/ocaml/typer/preprocess/lexer_raw.mll"
            ( return (INFIXOP4(Lexing.lexeme lexbuf)) )
# 2459 "src/ocaml/typer/lexer_raw.ml"

  | 89 ->
# 497 "src/ocaml/typer/preprocess/lexer_raw.mll"
            ( return PERCENT )
# 2464 "src/ocaml/typer/lexer_raw.ml"

  | 90 ->
# 499 "src/ocaml/typer/preprocess/lexer_raw.mll"
            ( return (INFIXOP3(Lexing.lexeme lexbuf)) )
# 2469 "src/ocaml/typer/lexer_raw.ml"

  | 91 ->
# 501 "src/ocaml/typer/preprocess/lexer_raw.mll"
            ( let s = Lexing.lexeme lexbuf in
              return (try Hashtbl.find state.keywords s
                      with Not_found -> SHARPOP s) )
# 2476 "src/ocaml/typer/lexer_raw.ml"

  | 92 ->
# 506 "src/ocaml/typer/preprocess/lexer_raw.mll"
            ( let s = Lexing.lexeme lexbuf in
              return (try Hashtbl.find state.keywords s
                      with Not_found -> SHARPOP s) )
# 2483 "src/ocaml/typer/lexer_raw.ml"

  | 93 ->
# 509 "src/ocaml/typer/preprocess/lexer_raw.mll"
        ( return EOF )
# 2488 "src/ocaml/typer/lexer_raw.ml"

  | 94 ->
# 512 "src/ocaml/typer/preprocess/lexer_raw.mll"
      ( fail (Illegal_character (Lexing.lexeme_char lexbuf 0))
              (Location.curr lexbuf)
      )
# 2495 "src/ocaml/typer/lexer_raw.ml"

  | __ocaml_lex_state -> __ocaml_lex_refill
      (fun lexbuf -> lexbuf.Lexing.refill_buff lexbuf;
         __ocaml_lex_token_rec state lexbuf __ocaml_lex_state) lexbuf

and comment state lexbuf =
   __ocaml_lex_comment_rec state lexbuf 143
and __ocaml_lex_comment_rec state lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 518 "src/ocaml/typer/preprocess/lexer_raw.mll"
      ( state.comment_start_loc <- (Location.curr lexbuf) :: state.comment_start_loc;
      Buffer.add_string state.buffer (Lexing.lexeme lexbuf);
      comment state lexbuf
    )
# 2511 "src/ocaml/typer/lexer_raw.ml"

  | 1 ->
# 523 "src/ocaml/typer/preprocess/lexer_raw.mll"
      ( match state.comment_start_loc with
        | [] -> assert false
        | [_] -> state.comment_start_loc <- []; return (Location.curr lexbuf)
        | _ :: l -> state.comment_start_loc <- l;
                  Buffer.add_string state.buffer (Lexing.lexeme lexbuf);
                  comment state lexbuf
       )
# 2522 "src/ocaml/typer/lexer_raw.ml"

  | 2 ->
# 531 "src/ocaml/typer/preprocess/lexer_raw.mll"
      (
        state.string_start_loc <- Location.curr lexbuf;
        Buffer.add_char state.buffer '\"';
        let buffer = state.buffer in
        state.buffer <- Buffer.create 15;
        (catch (string state lexbuf) (fun e l -> match e with
             | Unterminated_string ->
               begin match state.comment_start_loc with
                 | [] -> assert false
                 | loc :: _ ->
                   let start = List.hd (List.rev state.comment_start_loc) in
                   state.comment_start_loc <- [];
                   fail (Unterminated_string_in_comment (start, l)) loc
               end
             | e -> fail e l
           )
        ) >>= fun () ->
      state.string_start_loc <- Location.none;
      Buffer.add_string buffer (String.escaped (Buffer.contents state.buffer));
      state.buffer <- buffer;
      Buffer.add_char state.buffer '\"';
      comment state lexbuf )
# 2548 "src/ocaml/typer/lexer_raw.ml"

  | 3 ->
# 554 "src/ocaml/typer/preprocess/lexer_raw.mll"
      (
        let delim = Lexing.lexeme lexbuf in
        let delim = String.sub delim 1 (String.length delim - 2) in
        state.string_start_loc <- Location.curr lexbuf;
        Buffer.add_string state.buffer (Lexing.lexeme lexbuf);
        (catch (quoted_string state delim lexbuf) (fun e l -> match e with
             | Unterminated_string ->
               begin match state.comment_start_loc with
                 | [] -> assert false
                 | loc :: _ ->
                   let start = List.hd (List.rev state.comment_start_loc) in
                   state.comment_start_loc <- [];
                   fail (Unterminated_string_in_comment (start, l)) loc
               end
             | e -> fail e l
           )
        ) >>= fun () ->
        state.string_start_loc <- Location.none;
        Buffer.add_char state.buffer '|';
        Buffer.add_string state.buffer delim;
        Buffer.add_char state.buffer '}';
        comment state lexbuf )
# 2574 "src/ocaml/typer/lexer_raw.ml"

  | 4 ->
# 578 "src/ocaml/typer/preprocess/lexer_raw.mll"
      ( Buffer.add_string state.buffer (Lexing.lexeme lexbuf); comment state lexbuf )
# 2579 "src/ocaml/typer/lexer_raw.ml"

  | 5 ->
# 580 "src/ocaml/typer/preprocess/lexer_raw.mll"
      ( update_loc lexbuf None 1 false 1;
        Buffer.add_string state.buffer (Lexing.lexeme lexbuf);
        comment state lexbuf
      )
# 2587 "src/ocaml/typer/lexer_raw.ml"

  | 6 ->
# 585 "src/ocaml/typer/preprocess/lexer_raw.mll"
      ( Buffer.add_string state.buffer (Lexing.lexeme lexbuf); comment state lexbuf )
# 2592 "src/ocaml/typer/lexer_raw.ml"

  | 7 ->
# 587 "src/ocaml/typer/preprocess/lexer_raw.mll"
      ( Buffer.add_string state.buffer (Lexing.lexeme lexbuf); comment state lexbuf )
# 2597 "src/ocaml/typer/lexer_raw.ml"

  | 8 ->
# 589 "src/ocaml/typer/preprocess/lexer_raw.mll"
      ( Buffer.add_string state.buffer (Lexing.lexeme lexbuf); comment state lexbuf )
# 2602 "src/ocaml/typer/lexer_raw.ml"

  | 9 ->
# 591 "src/ocaml/typer/preprocess/lexer_raw.mll"
      ( Buffer.add_string state.buffer (Lexing.lexeme lexbuf); comment state lexbuf )
# 2607 "src/ocaml/typer/lexer_raw.ml"

  | 10 ->
# 593 "src/ocaml/typer/preprocess/lexer_raw.mll"
      ( match state.comment_start_loc with
        | [] -> assert false
        | loc :: _ ->
          let start = List.hd (List.rev state.comment_start_loc) in
          state.comment_start_loc <- [];
          fail (Unterminated_comment start) loc
      )
# 2618 "src/ocaml/typer/lexer_raw.ml"

  | 11 ->
# 601 "src/ocaml/typer/preprocess/lexer_raw.mll"
      ( update_loc lexbuf None 1 false 0;
        Buffer.add_string state.buffer (Lexing.lexeme lexbuf);
        comment state lexbuf
      )
# 2626 "src/ocaml/typer/lexer_raw.ml"

  | 12 ->
# 606 "src/ocaml/typer/preprocess/lexer_raw.mll"
      ( Buffer.add_string state.buffer (Lexing.lexeme lexbuf); comment state lexbuf )
# 2631 "src/ocaml/typer/lexer_raw.ml"

  | __ocaml_lex_state -> __ocaml_lex_refill
      (fun lexbuf -> lexbuf.Lexing.refill_buff lexbuf;
         __ocaml_lex_comment_rec state lexbuf __ocaml_lex_state) lexbuf

and string state lexbuf =
  lexbuf.Lexing.lex_mem <- Array.make 2 (-1); __ocaml_lex_string_rec state lexbuf 175
and __ocaml_lex_string_rec state lexbuf __ocaml_lex_state =
  match Lexing.new_engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 610 "src/ocaml/typer/preprocess/lexer_raw.mll"
      ( return () )
# 2644 "src/ocaml/typer/lexer_raw.ml"

  | 1 ->
let
# 611 "src/ocaml/typer/preprocess/lexer_raw.mll"
                                  space
# 2650 "src/ocaml/typer/lexer_raw.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_mem.(0) lexbuf.Lexing.lex_curr_pos in
# 612 "src/ocaml/typer/preprocess/lexer_raw.mll"
      ( update_loc lexbuf None 1 false (String.length space);
        string state lexbuf
      )
# 2656 "src/ocaml/typer/lexer_raw.ml"

  | 2 ->
# 616 "src/ocaml/typer/preprocess/lexer_raw.mll"
      ( Buffer.add_char state.buffer
          (char_for_backslash (Lexing.lexeme_char lexbuf 1));
        string state lexbuf )
# 2663 "src/ocaml/typer/lexer_raw.ml"

  | 3 ->
# 620 "src/ocaml/typer/preprocess/lexer_raw.mll"
      ( char_for_decimal_code state lexbuf 1 >>= fun c ->
        Buffer.add_char state.buffer c;
        string state lexbuf )
# 2670 "src/ocaml/typer/lexer_raw.ml"

  | 4 ->
# 624 "src/ocaml/typer/preprocess/lexer_raw.mll"
      ( Buffer.add_char state.buffer (char_for_hexadecimal_code lexbuf 2);
        string state lexbuf )
# 2676 "src/ocaml/typer/lexer_raw.ml"

  | 5 ->
# 627 "src/ocaml/typer/preprocess/lexer_raw.mll"
      ( if in_comment state
        then string state lexbuf
        else begin
(*  Should be an error, but we are very lax.
                  fail (Illegal_escape (Lexing.lexeme lexbuf),
                        (Location.curr lexbuf)
*)
          let loc = Location.curr lexbuf in
          Location.prerr_warning loc Warnings.Illegal_backslash;
          Buffer.add_char state.buffer (Lexing.lexeme_char lexbuf 0);
          Buffer.add_char state.buffer (Lexing.lexeme_char lexbuf 1);
          string state lexbuf
        end
      )
# 2694 "src/ocaml/typer/lexer_raw.ml"

  | 6 ->
# 642 "src/ocaml/typer/preprocess/lexer_raw.mll"
      ( if not (in_comment state) then
          Location.prerr_warning (Location.curr lexbuf) Warnings.Eol_in_string;
        update_loc lexbuf None 1 false 0;
        Buffer.add_string state.buffer (Lexing.lexeme lexbuf);
        string state lexbuf
      )
# 2704 "src/ocaml/typer/lexer_raw.ml"

  | 7 ->
# 649 "src/ocaml/typer/preprocess/lexer_raw.mll"
      ( let loc = state.string_start_loc in
        state.string_start_loc <- Location.none;
        fail Unterminated_string loc )
# 2711 "src/ocaml/typer/lexer_raw.ml"

  | 8 ->
# 653 "src/ocaml/typer/preprocess/lexer_raw.mll"
      ( Buffer.add_char state.buffer (Lexing.lexeme_char lexbuf 0);
        string state lexbuf )
# 2717 "src/ocaml/typer/lexer_raw.ml"

  | __ocaml_lex_state -> __ocaml_lex_refill
      (fun lexbuf -> lexbuf.Lexing.refill_buff lexbuf;
         __ocaml_lex_string_rec state lexbuf __ocaml_lex_state) lexbuf

and quoted_string state delim lexbuf =
   __ocaml_lex_quoted_string_rec state delim lexbuf 194
and __ocaml_lex_quoted_string_rec state delim lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 658 "src/ocaml/typer/preprocess/lexer_raw.mll"
      ( update_loc lexbuf None 1 false 0;
        Buffer.add_string state.buffer (Lexing.lexeme lexbuf);
        quoted_string state delim lexbuf
      )
# 2733 "src/ocaml/typer/lexer_raw.ml"

  | 1 ->
# 663 "src/ocaml/typer/preprocess/lexer_raw.mll"
      ( let loc = state.string_start_loc in
        state.string_start_loc <- Location.none;
        fail Unterminated_string loc )
# 2740 "src/ocaml/typer/lexer_raw.ml"

  | 2 ->
# 667 "src/ocaml/typer/preprocess/lexer_raw.mll"
      (
        let edelim = Lexing.lexeme lexbuf in
        let edelim = String.sub edelim 1 (String.length edelim - 2) in
        if delim = edelim then return ()
        else (Buffer.add_string state.buffer (Lexing.lexeme lexbuf);
              quoted_string state delim lexbuf)
      )
# 2751 "src/ocaml/typer/lexer_raw.ml"

  | 3 ->
# 675 "src/ocaml/typer/preprocess/lexer_raw.mll"
      ( Buffer.add_char state.buffer (Lexing.lexeme_char lexbuf 0);
        quoted_string state delim lexbuf )
# 2757 "src/ocaml/typer/lexer_raw.ml"

  | __ocaml_lex_state -> __ocaml_lex_refill
      (fun lexbuf -> lexbuf.Lexing.refill_buff lexbuf;
         __ocaml_lex_quoted_string_rec state delim lexbuf __ocaml_lex_state) lexbuf

and skip_sharp_bang state lexbuf =
   __ocaml_lex_skip_sharp_bang_rec state lexbuf 203
and __ocaml_lex_skip_sharp_bang_rec state lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 680 "src/ocaml/typer/preprocess/lexer_raw.mll"
      ( update_loc lexbuf None 3 false 0; token state lexbuf )
# 2770 "src/ocaml/typer/lexer_raw.ml"

  | 1 ->
# 682 "src/ocaml/typer/preprocess/lexer_raw.mll"
      ( update_loc lexbuf None 1 false 0; token state lexbuf )
# 2775 "src/ocaml/typer/lexer_raw.ml"

  | 2 ->
# 683 "src/ocaml/typer/preprocess/lexer_raw.mll"
       ( token state lexbuf )
# 2780 "src/ocaml/typer/lexer_raw.ml"

  | __ocaml_lex_state -> __ocaml_lex_refill
      (fun lexbuf -> lexbuf.Lexing.refill_buff lexbuf;
         __ocaml_lex_skip_sharp_bang_rec state lexbuf __ocaml_lex_state) lexbuf

;;

# 685 "src/ocaml/typer/preprocess/lexer_raw.mll"

  type comment = string * Location.t

  (* preprocessor support not implemented, not compatible with monadic
     interface *)

  let rec token_without_comments state lexbuf =
    token state lexbuf >>= function
    | COMMENT (s, comment_loc) ->
      token_without_comments state lexbuf
    | tok -> return tok

# 2801 "src/ocaml/typer/lexer_raw.ml"
